@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: cbanking.c,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: cbanking.c,v 1.2 2006/01/24 14:34:50 aquamaniac Exp $
+ cvs         : $Id: cbanking.c 847 2006-01-24 14:34:50Z aquamaniac $
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
