@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: gbanking_l.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: gbanking_l.h,v 1.1 2006/01/24 12:23:53 aquamaniac Exp $
+    cvs         : $Id: gbanking_l.h 843 2006-01-24 12:23:53Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
