@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: gbanking_p.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: gbanking_p.h,v 1.3 2006/01/24 14:34:50 aquamaniac Exp $
+    cvs         : $Id: gbanking_p.h 847 2006-01-24 14:34:50Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
