@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: gbjobview.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: gbjobview.h,v 1.3 2006/02/21 17:04:53 aquamaniac Exp $
+    cvs         : $Id: gbjobview.h 947 2006-02-21 17:04:54Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
