@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: gbjobview_p.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: gbjobview_p.h,v 1.1 2006/01/24 18:25:23 aquamaniac Exp $
+    cvs         : $Id: gbjobview_p.h 849 2006-01-24 18:25:23Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
