@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: gbprofileview.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: gbprofileview.h,v 1.1 2006/01/24 18:33:33 aquamaniac Exp $
+    cvs         : $Id: gbprofileview.h 851 2006-01-24 18:33:33Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
