@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: kbflagstaff.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: kbflagstaff.h,v 1.1 2005/08/08 15:26:33 aquamaniac Exp $
+    cvs         : $Id: kbflagstaff.h 440 2005-08-08 15:26:33Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
