@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: jobview.cpp,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: jobview.cpp,v 1.3 2005/08/09 15:25:46 aquamaniac Exp $
+    cvs         : $Id: jobview.cpp 470 2005-08-09 15:25:47Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
