@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: qbcfgtabpageaccounts.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: qbcfgtabpageaccounts.h,v 1.5 2006/01/20 14:15:15 cstim Exp $
+    cvs         : $Id: qbcfgtabpageaccounts.h 809 2006-01-20 14:15:15Z cstim $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
