@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: qbeditaccount.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: qbeditaccount.h,v 1.5 2006/01/20 14:52:36 aquamaniac Exp $
+    cvs         : $Id: qbeditaccount.h 811 2006-01-20 14:52:36Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
