@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: qbedituser.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: qbedituser.h,v 1.6 2006/01/26 03:34:53 aquamaniac Exp $
+    cvs         : $Id: qbedituser.h 857 2006-01-26 03:34:55Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
