@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: qbimporter.cpp,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: qbimporter.cpp,v 1.7 2006/03/24 00:52:10 aquamaniac Exp $
+    cvs         : $Id: qbimporter.cpp 978 2006-03-24 00:52:10Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
