@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: qbprintdialog.cpp,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: qbprintdialog.cpp,v 1.6 2006/01/23 16:31:00 aquamaniac Exp $
+    cvs         : $Id: qbprintdialog.cpp 837 2006-01-23 16:31:01Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
