@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: qbanking.cpp,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: qbanking.cpp,v 1.10 2006/02/14 02:11:53 aquamaniac Exp $
+    cvs         : $Id: qbanking.cpp 1029 2006-06-13 09:18:51Z martin $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -219,7 +219,7 @@ int QBanking::inputBox(GWEN_TYPE_UINT32 flags,
 
     s=ib.getInput();
     int len=s.length();
-    if (len && len<maxLen-1) {
+    if (len && len<maxLen) {
       // FIXME: QString::latin1() is most probably wrong here!
       // This means that the entered string will be passed into
       // AQ_BANKING in latin1 encoding, not in utf8. This should
@@ -883,7 +883,7 @@ int QBanking::init(){
 			  QMessageBox::Ok,QMessageBox::NoButton);
     delete _simpleCallback;
     _simpleCallback=0;
-    return false;
+    return -1;
   }
 
   _fastCallback=new QBFastCallback(GWEN_WAITCALLBACK_ID_FAST);
@@ -904,7 +904,7 @@ int QBanking::init(){
 			  QMessageBox::Ok,QMessageBox::NoButton);
     delete _fastCallback;
     _fastCallback=0;
-    return false;
+    return -1;
   }
 
   /* create cfg module plugin manager */
@@ -920,7 +920,7 @@ int QBanking::init(){
   if (GWEN_PluginManager_Register(pm)) {
     DBG_ERROR(0,
               "Could not register cfg module plugin manager");
-    return false;
+    return -1;
   }
   _pluginManagerCfgModules=pm;
 
