@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: qbflagstaff.cpp,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: qbflagstaff.cpp,v 1.3 2006/01/20 20:21:35 aquamaniac Exp $
+    cvs         : $Id: qbflagstaff.cpp 816 2006-01-20 20:21:36Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
