@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: qbwcb_fast.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: qbwcb_fast.h,v 1.2 2006/01/13 13:59:56 cstim Exp $
+    cvs         : $Id: qbwcb_fast.h 764 2006-01-13 14:00:00Z cstim $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
