@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: account.h,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: account.h,v 1.16 2006/02/22 19:38:54 aquamaniac Exp $
+ cvs         : $Id: account.h 950 2006-02-22 19:39:02Z aquamaniac $
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
