@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: banking_be.h,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: banking_be.h,v 1.10 2006/02/24 03:07:58 aquamaniac Exp $
+ cvs         : $Id: banking_be.h 953 2006-02-24 03:07:59Z aquamaniac $
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
