@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: banking_p.h,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: banking_p.h,v 1.44 2006/02/24 03:07:58 aquamaniac Exp $
+ cvs         : $Id: banking_p.h 1029 2006-06-13 09:18:51Z martin $
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
@@ -50,6 +50,7 @@
 struct AB_BANKING {
   GWEN_INHERIT_ELEMENT(AB_BANKING)
   int isOpen;
+  int isBasicsOpen;
   char *appName;
   char *appEscName;
   int appExtensions;
@@ -236,4 +237,9 @@ static void AB_Banking__DistribContextAmongJobs(AB_IMEXPORTER_CONTEXT *ctx,
                                                 AB_JOB_LIST2 *jl2);
 
 
+static AB_IMEXPORTER_ACCOUNTINFO*
+  AB_Banking__FindAccountInfo(AB_IMEXPORTER_CONTEXT *ctx,
+                              const AB_ACCOUNT *a);
+
+
 #endif /* AQBANKING_BANKING_P_H */
