@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: country.c,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: country.c,v 1.6 2005/09/21 07:51:57 cstim Exp $
+ cvs         : $Id: country.c 624 2005-09-21 07:51:57Z cstim $
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
