@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: country_l.h,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: country_l.h,v 1.1 2005/02/17 07:54:40 aquamaniac Exp $
+ cvs         : $Id: country_l.h 214 2005-02-17 07:54:40Z aquamaniac $
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
