@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: cryptmanager.c,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: cryptmanager.c,v 1.5 2006/01/23 05:16:26 aquamaniac Exp $
+ cvs         : $Id: cryptmanager.c 829 2006-01-23 05:16:27Z aquamaniac $
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
