@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: httpsession.c,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: httpsession.c,v 1.4 2006/02/14 02:11:53 aquamaniac Exp $
+    cvs         : $Id: httpsession.c 935 2006-02-14 02:11:55Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
