@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: httpsession_p.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: httpsession_p.h,v 1.1 2006/02/03 17:42:43 aquamaniac Exp $
+    cvs         : $Id: httpsession_p.h 915 2006-02-03 17:42:43Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
