@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: i18n_l.h,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: i18n_l.h,v 1.1 2005/01/22 20:40:30 aquamaniac Exp $
+ cvs         : $Id: i18n_l.h 197 2005-01-22 20:40:33Z aquamaniac $
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
