@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: imexporter.c,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: imexporter.c,v 1.27 2006/03/27 17:27:01 aquamaniac Exp $
+ cvs         : $Id: imexporter.c 1038 2006-07-03 03:01:30Z martin $
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
@@ -270,7 +270,9 @@ void AB_ImExporterAccountInfo_free(AB_IMEXPORTER_ACCOUNTINFO *iea){
     free(iea->bankName);
     free(iea->accountNumber);
     free(iea->accountName);
+    free(iea->iban);
     free(iea->owner);
+    free(iea->currency);
     free(iea->description);
     AB_Transaction_List_free(iea->notedTransactions);
     AB_Transaction_List_free(iea->datedTransfers);
@@ -299,7 +301,9 @@ AB_ImExporterAccountInfo_dup(const AB_IMEXPORTER_ACCOUNTINFO *oi) {
   COPY_CHAR(bankName);
   COPY_CHAR(accountNumber);
   COPY_CHAR(accountName);
+  COPY_CHAR(iban);
   COPY_CHAR(owner);
+  COPY_CHAR(currency);
   COPY_CHAR(description);
   iea->accountType=oi->accountType;
 #undef COPY_CHAR
@@ -331,7 +335,9 @@ int AB_ImExporterAccountInfo_toDb(const AB_IMEXPORTER_ACCOUNTINFO *iea,
   STORE_CHAR(bankName);
   STORE_CHAR(accountNumber);
   STORE_CHAR(accountName);
+  STORE_CHAR(iban);
   STORE_CHAR(owner);
+  STORE_CHAR(currency);
   STORE_CHAR(description);
   STORE_INT(accountType);
 #undef STORE_CHAR
@@ -486,7 +492,6 @@ int AB_ImExporterAccountInfo_toDb(const AB_IMEXPORTER_ACCOUNTINFO *iea,
 }
 
 
-
 AB_IMEXPORTER_ACCOUNTINFO*
 AB_ImExporterAccountInfo_fromDb(GWEN_DB_NODE *db){
   AB_IMEXPORTER_ACCOUNTINFO *iea;
@@ -504,7 +509,9 @@ AB_ImExporterAccountInfo_fromDb(GWEN_DB_NODE *db){
   RESTORE_CHAR(bankCode);
   RESTORE_CHAR(bankName);
   RESTORE_CHAR(accountNumber);
+  RESTORE_CHAR(iban);
   RESTORE_CHAR(owner);
+  RESTORE_CHAR(currency);
   RESTORE_CHAR(description);
   RESTORE_INT(accountType, AB_AccountType_Bank);
 #undef RESTORE_CHAR
@@ -890,6 +897,42 @@ void AB_ImExporterAccountInfo_SetAccountNumber(AB_IMEXPORTER_ACCOUNTINFO *iea,
 
 
 
+const char*
+AB_ImExporterAccountInfo_GetIban(const AB_IMEXPORTER_ACCOUNTINFO *iea) {
+  assert(iea);
+  return iea->iban;
+}
+
+
+
+void AB_ImExporterAccountInfo_SetIban(AB_IMEXPORTER_ACCOUNTINFO *iea,
+                                      const char *s) {
+  assert(iea);
+  free(iea->iban);
+  if (s) iea->iban=strdup(s);
+  else iea->iban=0;
+}
+
+
+
+const char*
+AB_ImExporterAccountInfo_GetCurrency(const AB_IMEXPORTER_ACCOUNTINFO *iea) {
+  assert(iea);
+  return iea->currency;
+}
+
+
+
+void AB_ImExporterAccountInfo_SetCurrency(AB_IMEXPORTER_ACCOUNTINFO *iea,
+                                          const char *s) {
+  assert(iea);
+  free(iea->currency);
+  if (s) iea->currency=strdup(s);
+  else iea->currency=0;
+}
+
+
+
 const char*
 AB_ImExporterAccountInfo_GetAccountName(const AB_IMEXPORTER_ACCOUNTINFO *iea){
   assert(iea);
@@ -1060,11 +1103,10 @@ int AB_ImExporterContext_toDb(const AB_IMEXPORTER_CONTEXT *iec,
 
 
 
-AB_IMEXPORTER_CONTEXT *AB_ImExporterContext_fromDb(GWEN_DB_NODE *db) {
-  AB_IMEXPORTER_CONTEXT *iec;
+int AB_ImExporterContext_ReadDb(AB_IMEXPORTER_CONTEXT *iec,
+                                GWEN_DB_NODE *db) {
   GWEN_DB_NODE *dbT;
 
-  iec=AB_ImExporterContext_new();
   dbT=GWEN_DB_GetGroup(db, GWEN_PATH_FLAGS_NAMEMUSTEXIST,
 		       "accountInfoList");
   if (dbT) {
@@ -1079,6 +1121,16 @@ AB_IMEXPORTER_CONTEXT *AB_ImExporterContext_fromDb(GWEN_DB_NODE *db) {
     }
   }
 
+  return 0;
+}
+
+
+
+AB_IMEXPORTER_CONTEXT *AB_ImExporterContext_fromDb(GWEN_DB_NODE *db) {
+  AB_IMEXPORTER_CONTEXT *iec;
+
+  iec=AB_ImExporterContext_new();
+  AB_ImExporterContext_ReadDb(iec, db);
   return iec;
 }
 
@@ -1539,6 +1591,12 @@ int AH_ImExporter_DbFromIso8859_1ToUtf8(GWEN_DB_NODE *db) {
 
 
 
+int AB_ImExporter_DbFromIso8859_1ToUtf8(GWEN_DB_NODE *db) {
+  return AH_ImExporter__Transform_Group(db, 0);
+}
+
+
+
 void AB_ImExporterContext_AddContext(AB_IMEXPORTER_CONTEXT *iec,
                                      AB_IMEXPORTER_CONTEXT *toAdd) {
   AB_IMEXPORTER_ACCOUNTINFO *iea;
