@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: imexporter.h,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: imexporter.h,v 1.26 2006/02/24 03:07:58 aquamaniac Exp $
+ cvs         : $Id: imexporter.h 1038 2006-07-03 03:01:30Z martin $
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
@@ -166,6 +166,11 @@ AQBANKING_API
 AB_IMEXPORTER_CONTEXT *AB_ImExporterContext_fromDb(GWEN_DB_NODE *db);
 
 
+AQBANKING_API 
+int AB_ImExporterContext_ReadDb(AB_IMEXPORTER_CONTEXT *iec,
+                                GWEN_DB_NODE *db);
+
+
 /**
  * Adds the content of the second context to the first one.
  * Frees the second context.
@@ -348,6 +353,28 @@ AQBANKING_API
 void AB_ImExporterAccountInfo_SetAccountName(AB_IMEXPORTER_ACCOUNTINFO *iea,
                                              const char *s);
 
+/**
+ * IBAN.
+ */
+AQBANKING_API 
+const char*
+AB_ImExporterAccountInfo_GetIban(const AB_IMEXPORTER_ACCOUNTINFO *iea);
+AQBANKING_API 
+void AB_ImExporterAccountInfo_SetIban(AB_IMEXPORTER_ACCOUNTINFO *iea,
+                                      const char *s);
+
+/**
+ * Account currency
+ */
+AQBANKING_API 
+const char*
+AB_ImExporterAccountInfo_GetCurrency(const AB_IMEXPORTER_ACCOUNTINFO *iea);
+
+AQBANKING_API 
+void AB_ImExporterAccountInfo_SetCurrency(AB_IMEXPORTER_ACCOUNTINFO *iea,
+                                          const char *s);
+
+
 /**
  * Name of the account' owner.
  * Used when importing data, not used when exporting.
@@ -739,12 +766,15 @@ void AB_ImExporter_Iso8859_1ToUtf8(const char *p,
                                    int size,
                                    GWEN_BUFFER *buf);
 
+AQBANKING_DEPRECATED AQBANKING_API
+int AH_ImExporter_DbFromIso8859_1ToUtf8(GWEN_DB_NODE *db);
+
 /**
  * This function call @ref AB_ImExporter_Iso8859_1ToUtf8 on all char
  * values in the given db.
  */
 AQBANKING_API 
-int AH_ImExporter_DbFromIso8859_1ToUtf8(GWEN_DB_NODE *db);
+int AB_ImExporter_DbFromIso8859_1ToUtf8(GWEN_DB_NODE *db);
 
 AQBANKING_API 
 GWEN_TIME *AB_ImExporter_DateFromString(const char *p,
