@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: job_l.h,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: job_l.h,v 1.7 2005/09/02 01:57:29 aquamaniac Exp $
+ cvs         : $Id: job_l.h 586 2005-09-02 01:57:29Z aquamaniac $
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
