@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: jobeutransfer_l.h,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: jobeutransfer_l.h,v 1.1 2005/03/22 21:52:04 aquamaniac Exp $
+ cvs         : $Id: jobeutransfer_l.h 247 2005-03-22 21:52:04Z aquamaniac $
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
