@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: jobgetdatedtransfers.h,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: jobgetdatedtransfers.h,v 1.4 2006/02/21 17:04:54 aquamaniac Exp $
+ cvs         : $Id: jobgetdatedtransfers.h 947 2006-02-21 17:04:54Z aquamaniac $
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
