@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: jobgetstandingorders.h,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: jobgetstandingorders.h,v 1.3 2006/02/16 21:32:19 aquamaniac Exp $
+ cvs         : $Id: jobgetstandingorders.h 943 2006-02-16 21:32:19Z aquamaniac $
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
