@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: jobmodifysto_l.h,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: jobmodifysto_l.h,v 1.1 2006/02/14 02:44:12 aquamaniac Exp $
+ cvs         : $Id: jobmodifysto_l.h 937 2006-02-14 02:44:12Z aquamaniac $
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
