@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: msgengine.c,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: msgengine.c,v 1.2 2005/12/23 02:16:23 aquamaniac Exp $
+    cvs         : $Id: msgengine.c 727 2005-12-23 02:16:25Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
