@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: msgengine_p.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: msgengine_p.h,v 1.3 2006/01/17 11:57:39 aquamaniac Exp $
+    cvs         : $Id: msgengine_p.h 796 2006-01-17 11:57:39Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
