@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: provider_l.h,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: provider_l.h,v 1.12 2006/02/16 21:32:19 aquamaniac Exp $
+ cvs         : $Id: provider_l.h 943 2006-02-16 21:32:19Z aquamaniac $
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
