@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: provider_p.h,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: provider_p.h,v 1.13 2006/02/10 12:10:18 cstim Exp $
+ cvs         : $Id: provider_p.h 933 2006-02-10 12:10:18Z cstim $
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
