@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: accstatus_p.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: accstatus_p.h,v 1.3 2006/01/13 13:59:57 cstim Exp $
+    cvs         : $Id: accstatus_p.h 764 2006-01-13 14:00:00Z cstim $
     begin       : Mon Apr 05 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
