@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: balance.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: balance.h,v 1.4 2005/02/24 04:00:02 aquamaniac Exp $
+    cvs         : $Id: balance.h 1009 2006-05-11 19:59:20Z martin $
     begin       : Mon Apr 05 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -24,7 +24,7 @@ extern "C" {
 typedef struct AB_BALANCE AB_BALANCE;
 
 AQBANKING_API 
-AB_BALANCE *AB_Balance_new(AB_VALUE *v, const GWEN_TIME *t);
+AB_BALANCE *AB_Balance_new(const AB_VALUE *v, const GWEN_TIME *t);
 AQBANKING_API 
 AB_BALANCE *AB_Balance_fromDb(GWEN_DB_NODE *db);
 AQBANKING_API 
