@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: balance_p.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: balance_p.h,v 1.1.1.1 2004/07/30 10:32:09 aquamaniac Exp $
+    cvs         : $Id: balance_p.h 2 2004-07-30 10:32:05Z aquamaniac $
     begin       : Mon Apr 05 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
