@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: transactionfns.h,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: transactionfns.h,v 1.2 2005/12/01 12:46:15 cstim Exp $
+ cvs         : $Id: transactionfns.h 705 2005-12-01 12:46:15Z cstim $
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
