@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: value.c,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: value.c,v 1.11 2006/03/15 09:51:47 aquamaniac Exp $
+    cvs         : $Id: value.c 963 2006-03-15 09:51:49Z aquamaniac $
     begin       : Mon Apr 05 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
