@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: value_p.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: value_p.h,v 1.2 2005/02/22 10:25:15 cstim Exp $
+    cvs         : $Id: value_p.h 223 2005-02-22 10:25:15Z cstim $
     begin       : Mon Apr 05 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
