@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: account.c,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: account.c,v 1.2 2006/01/13 13:59:57 cstim Exp $
+ cvs         : $Id: account.c 764 2006-01-13 14:00:00Z cstim $
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
