@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: aqdtaus-plugin.c,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: aqdtaus-plugin.c,v 1.2 2006/01/13 13:59:57 cstim Exp $
+    cvs         : $Id: aqdtaus-plugin.c 764 2006-01-13 14:00:00Z cstim $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
