@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: provider_p.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: provider_p.h,v 1.3 2006/01/15 21:27:47 aquamaniac Exp $
+    cvs         : $Id: provider_p.h 788 2006-01-15 21:27:47Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
