@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: cfgmoduledtaus.cpp,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: cfgmoduledtaus.cpp,v 1.2 2006/01/13 13:59:58 cstim Exp $
+    cvs         : $Id: cfgmoduledtaus.cpp 764 2006-01-13 14:00:00Z cstim $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
