@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: card_l.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: card_l.h,v 1.2 2006/01/13 16:51:44 cstim Exp $
+    cvs         : $Id: card_l.h 776 2006-01-13 16:51:44Z cstim $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
