@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: cfgtabpagk.h,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: cfgtabpagk.h,v 1.1 2006/01/14 11:23:54 cstim Exp $
+ cvs         : $Id: cfgtabpagk.h 780 2006-01-14 11:23:54Z cstim $
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
