@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: version.h.in,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: version.h.in,v 1.1 2005/08/08 02:27:20 aquamaniac Exp $
+ cvs         : $Id: version.h.in 419 2005-08-08 02:27:20Z aquamaniac $
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
@@ -15,12 +15,12 @@
 #define AQGELDKARTE_VERSION_H
 
 #define AQGELDKARTE_VERSION_MAJOR 2
-#define AQGELDKARTE_VERSION_MINOR 0
-#define AQGELDKARTE_VERSION_PATCHLEVEL 0
+#define AQGELDKARTE_VERSION_MINOR 2
+#define AQGELDKARTE_VERSION_PATCHLEVEL 3
 #define AQGELDKARTE_VERSION_BUILD 0
 #define AQGELDKARTE_VERSION_TAG "stable"
-#define AQGELDKARTE_VERSION_FULL_STRING "2.0.0.0stable"
-#define AQGELDKARTE_VERSION_STRING "2.0.0"
+#define AQGELDKARTE_VERSION_FULL_STRING "2.2.3.0-stable"
+#define AQGELDKARTE_VERSION_STRING "2.2.3"
 
 
 
