@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: jobgetdatedxfers.c,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: jobgetdatedxfers.c,v 1.3 2006/02/14 02:11:54 aquamaniac Exp $
+    cvs         : $Id: jobgetdatedxfers.c 935 2006-02-14 02:11:55Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
