@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: jobgettransactions.c,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: jobgettransactions.c,v 1.6 2006/02/16 21:32:19 aquamaniac Exp $
+    cvs         : $Id: jobgettransactions.c 943 2006-02-16 21:32:19Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
