@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: jobmultitransfer.c,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: jobmultitransfer.c,v 1.6 2006/02/22 19:38:57 aquamaniac Exp $
+    cvs         : $Id: jobmultitransfer.c 950 2006-02-22 19:39:02Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
