@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: adminjobs.c,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: adminjobs.c,v 1.5 2006/02/22 19:38:57 aquamaniac Exp $
+    cvs         : $Id: adminjobs.c 1051 2006-07-18 12:01:39Z martin $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -610,22 +610,10 @@ int AH_Job_UpdateBank_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx){
       AB_Account_SetBankCode(acc, bankCode);
       AB_Account_SetAccountNumber(acc, accountId);
 
-      if (accountName) {
-        GWEN_BUFFER *xbuf;
-
-        xbuf=GWEN_Buffer_new(0, 32, 0, 1);
-        AH_HBCI_HbciToUtf8(accountName, 0, xbuf);
-        AB_Account_SetAccountName(acc, GWEN_Buffer_GetStart(xbuf));
-        GWEN_Buffer_free(xbuf);
-      }
-      if (userName) {
-        GWEN_BUFFER *xbuf;
-
-        xbuf=GWEN_Buffer_new(0, 32, 0, 1);
-        AH_HBCI_HbciToUtf8(userName, 0, xbuf);
-        AB_Account_SetOwnerName(acc, GWEN_Buffer_GetStart(xbuf));
-        GWEN_Buffer_free(xbuf);
-      }
+      if (accountName)
+        AB_Account_SetAccountName(acc, accountName);
+      if (userName)
+        AB_Account_SetOwnerName(acc, userName);
 
       AB_Account_List2_PushBack(jd->accountList, acc);
     }
@@ -910,7 +898,7 @@ int AH_Job_TestVersion_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx){
 	int code;
 
 	DBG_INFO(AQHBCI_LOGDOMAIN, "Found message result");
-        code=GWEN_DB_GetIntValue(dbResult, "code", 0, -1);
+        code=GWEN_DB_GetIntValue(dbResult, "resultCode", 0, -1);
 	if (code>=9000) {
 	  if (code==9180) {
 	    /* version is definately not supported */
@@ -1086,6 +1074,437 @@ int AH_Job_GetStatus_Exchange(AH_JOB *j, AB_JOB *bj,
 
 
 
+/* __________________________________________________________________________
+ * AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
+ *                             AH_Job_Tan
+ * YYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYY
+ */
+
+
+GWEN_INHERIT(AH_JOB, AH_JOB_TAN);
+
+
+AH_JOB *AH_Job_Tan_new(AB_USER *u, int process) {
+  AH_JOB *j;
+  AH_JOB_TAN *aj;
+  GWEN_DB_NODE *dbArgs;
+  GWEN_DB_NODE *dbParams;
+
+  j=AH_Job_new("JobTan", u, 0);
+  if (!j)
+    return 0;
+
+  GWEN_NEW_OBJECT(AH_JOB_TAN, aj);
+  GWEN_INHERIT_SETDATA(AH_JOB, AH_JOB_TAN, j, aj,
+                       AH_Job_Tan_FreeData);
+  /* overwrite some virtual functions */
+  AH_Job_SetProcessFn(j, AH_Job_Tan_Process);
+  AH_Job_SetExchangeFn(j, AH_Job_Tan_Exchange);
+
+  /* set some known arguments */
+  dbArgs=AH_Job_GetArguments(j);
+  assert(dbArgs);
+  dbParams=AH_Job_GetParams(j);
+  assert(dbParams);
+
+  GWEN_DB_SetIntValue(dbArgs, GWEN_DB_FLAGS_OVERWRITE_VARS,
+                      "process", process);
+  if (process==1 || process==2)
+    GWEN_DB_SetCharValue(dbArgs, GWEN_DB_FLAGS_OVERWRITE_VARS,
+                         "moreTans", "N");
+  return j;
+}
+
+
+
+void AH_Job_Tan_FreeData(void *bp, void *p){
+  AH_JOB_TAN *aj;
+
+  aj=(AH_JOB_TAN*)p;
+  free(aj->reference);
+  free(aj->challenge);
+  GWEN_FREE_OBJECT(aj);
+}
+
+
+
+int AH_Job_Tan_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx){
+  AH_JOB_TAN *aj;
+  GWEN_DB_NODE *dbResponses;
+  GWEN_DB_NODE *dbCurr;
+  int rv;
+
+  DBG_NOTICE(AQHBCI_LOGDOMAIN, "Processing JobTan");
+  assert(j);
+  aj=GWEN_INHERIT_GETDATA(AH_JOB, AH_JOB_TAN, j);
+  assert(aj);
+
+  dbResponses=AH_Job_GetResponses(j);
+  assert(dbResponses);
+
+  /* search for "TanResponse" */
+  dbCurr=GWEN_DB_GetFirstGroup(dbResponses);
+  while(dbCurr) {
+    GWEN_DB_NODE *dbTanResponse;
+
+    rv=AH_Job_CheckEncryption(j, dbCurr);
+    if (rv) {
+      DBG_NOTICE(AQHBCI_LOGDOMAIN, "Compromised security (encryption)");
+      AH_Job_SetStatus(j, AH_JobStatusError);
+      return rv;
+    }
+    rv=AH_Job_CheckSignature(j, dbCurr);
+    if (rv) {
+      DBG_NOTICE(AQHBCI_LOGDOMAIN, "Compromised security (signature)");
+      AH_Job_SetStatus(j, AH_JobStatusError);
+      return rv;
+    }
+
+    dbTanResponse=GWEN_DB_GetGroup(dbCurr, GWEN_PATH_FLAGS_NAMEMUSTEXIST,
+                                   "data/tanResponse");
+    if (dbTanResponse) {
+      const char *s;
+
+      DBG_NOTICE(AQHBCI_LOGDOMAIN, "Got a TAN response");
+      if (GWEN_Logger_GetLevel(0)>=GWEN_LoggerLevelDebug)
+        GWEN_DB_Dump(dbTanResponse, stderr, 2);
+
+      s=GWEN_DB_GetCharValue(dbTanResponse, "challenge", 0, 0);
+      if (s) {
+        free(aj->challenge);
+        aj->challenge=strdup(s);
+      }
+
+      s=GWEN_DB_GetCharValue(dbTanResponse, "jobReference", 0, 0);
+      if (s) {
+        free(aj->reference);
+        aj->reference=strdup(s);
+      }
+
+      break; /* break loop, we found the tanResponse */
+    } /* if "TanResponse" */
+    dbCurr=GWEN_DB_GetNextGroup(dbCurr);
+  }
+
+  return 0;
+}
+
+
+
+int AH_Job_Tan_Exchange(AH_JOB *j, AB_JOB *bj,
+                        AH_JOB_EXCHANGE_MODE m){
+  AH_JOB_TAN *aj;
+
+  DBG_WARN(AQHBCI_LOGDOMAIN, "Exchanging (%d)", m);
+  assert(j);
+  aj=GWEN_INHERIT_GETDATA(AH_JOB, AH_JOB_TAN, j);
+  assert(aj);
+
+  switch(m) {
+  case AH_Job_ExchangeModeParams:
+    break;
+  case AH_Job_ExchangeModeArgs:
+    break;
+  case AH_Job_ExchangeModeResults:
+    break;
+  default:
+    DBG_NOTICE(AQHBCI_LOGDOMAIN, "Unsupported exchange mode");
+    return AB_ERROR_NOT_SUPPORTED;
+  } /* switch */
+
+  return 0;
+}
+
+
+
+void AH_Job_Tan_SetHash(AH_JOB *j,
+                        const unsigned char *p,
+                        unsigned int len) {
+  AH_JOB_TAN *aj;
+  GWEN_DB_NODE *dbArgs;
+
+  assert(j);
+  aj=GWEN_INHERIT_GETDATA(AH_JOB, AH_JOB_TAN, j);
+  assert(aj);
+
+  dbArgs=AH_Job_GetArguments(j);
+  assert(dbArgs);
+
+  GWEN_DB_SetBinValue(dbArgs, GWEN_DB_FLAGS_OVERWRITE_VARS,
+                      "jobHash", p, len);
+
+}
+
+
+
+void AH_Job_Tan_SetReference(AH_JOB *j, const char *p) {
+  AH_JOB_TAN *aj;
+  GWEN_DB_NODE *dbArgs;
+
+  assert(j);
+  aj=GWEN_INHERIT_GETDATA(AH_JOB, AH_JOB_TAN, j);
+  assert(aj);
+
+  dbArgs=AH_Job_GetArguments(j);
+  assert(dbArgs);
+
+  GWEN_DB_SetCharValue(dbArgs, GWEN_DB_FLAGS_OVERWRITE_VARS,
+                       "jobReference", p);
+}
+
+
+
+void AH_Job_Tan_SetTanList(AH_JOB *j, const char *p) {
+  AH_JOB_TAN *aj;
+  GWEN_DB_NODE *dbArgs;
+
+  assert(j);
+  aj=GWEN_INHERIT_GETDATA(AH_JOB, AH_JOB_TAN, j);
+  assert(aj);
+
+  dbArgs=AH_Job_GetArguments(j);
+  assert(dbArgs);
+
+  GWEN_DB_SetCharValue(dbArgs, GWEN_DB_FLAGS_OVERWRITE_VARS,
+                       "tanList", p);
+}
+
+
+
+void AH_Job_Tan_SetTanInfo(AH_JOB *j, const char *p) {
+  AH_JOB_TAN *aj;
+  GWEN_DB_NODE *dbArgs;
+
+  assert(j);
+  aj=GWEN_INHERIT_GETDATA(AH_JOB, AH_JOB_TAN, j);
+  assert(aj);
+
+  dbArgs=AH_Job_GetArguments(j);
+  assert(dbArgs);
+
+  GWEN_DB_SetCharValue(dbArgs, GWEN_DB_FLAGS_OVERWRITE_VARS,
+                       "tanInfo", p);
+}
+
+
+
+const char *AH_Job_Tan_GetChallenge(const AH_JOB *j) {
+  AH_JOB_TAN *aj;
+
+  assert(j);
+  aj=GWEN_INHERIT_GETDATA(AH_JOB, AH_JOB_TAN, j);
+  assert(aj);
+
+  return aj->challenge;
+}
+
+
+
+const char *AH_Job_Tan_GetReference(const AH_JOB *j) {
+  AH_JOB_TAN *aj;
+
+  assert(j);
+  aj=GWEN_INHERIT_GETDATA(AH_JOB, AH_JOB_TAN, j);
+  assert(aj);
+
+  return aj->reference;
+}
+
+
+
+/* __________________________________________________________________________
+ * AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
+ *                             AH_Job_GetItanModes
+ * YYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYY
+ */
+
+GWEN_INHERIT(AH_JOB, AH_JOB_GETITANMODES);
+
+
+AH_JOB *AH_Job_GetItanModes_new(AB_USER *u){
+  AH_JOB *j;
+  GWEN_DB_NODE *args;
+  AH_JOB_GETITANMODES *jd;
+
+  assert(u);
+  j=AH_Job_new("JobGetItanModes", u, 0);
+  if (!j) {
+    DBG_ERROR(AQHBCI_LOGDOMAIN,
+              "JobGetItanModes not supported, should not happen");
+    return 0;
+  }
+  GWEN_NEW_OBJECT(AH_JOB_GETITANMODES, jd);
+  GWEN_INHERIT_SETDATA(AH_JOB, AH_JOB_GETITANMODES, j, jd,
+                       AH_Job_GetItanModes_FreeData);
+  AH_Job_SetProcessFn(j, AH_Job_GetItanModes_Process);
+
+  jd->modes=0;
+
+  /* set arguments */
+  args=AH_Job_GetArguments(j);
+  assert(args);
+  GWEN_DB_SetIntValue(args, GWEN_DB_FLAGS_OVERWRITE_VARS,
+                      "prepare/bpdversion", 0);
+  GWEN_DB_SetIntValue(args, GWEN_DB_FLAGS_OVERWRITE_VARS,
+                      "prepare/updversion", 0);
+
+  DBG_INFO(AQHBCI_LOGDOMAIN, "JobGetItanModes created");
+  return j;
+}
+
+
+
+void AH_Job_GetItanModes_FreeData(void *bp, void *p){
+  AH_JOB_GETITANMODES *jd;
+
+  jd=(AH_JOB_GETITANMODES*)p;
+  GWEN_FREE_OBJECT(jd);
+}
+
+
+
+int AH_Job_GetItanModes_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx){
+  AH_JOB_GETITANMODES *jd;
+  GWEN_DB_NODE *dbResponses;
+  GWEN_DB_NODE *dbCurr;
+  GWEN_DB_NODE *dbMsgResponse;
+
+  assert(j);
+  jd=GWEN_INHERIT_GETDATA(AH_JOB, AH_JOB_GETITANMODES, j);
+  assert(jd);
+
+  jd->modes=0;
+
+  dbResponses=AH_Job_GetResponses(j);
+  assert(dbResponses);
+
+  DBG_DEBUG(AQHBCI_LOGDOMAIN, "Parsing this response");
+  if (GWEN_Logger_GetLevel(AQHBCI_LOGDOMAIN)>=GWEN_LoggerLevelDebug)
+    GWEN_DB_Dump(dbResponses, stderr, 2);
+
+  /* search for "SegResult" */
+  dbCurr=GWEN_DB_GetFirstGroup(dbResponses);
+
+  while(dbCurr) {
+    dbMsgResponse=GWEN_DB_GetGroup(dbCurr, GWEN_PATH_FLAGS_NAMEMUSTEXIST,
+                                   "data/SegResult");
+    if (dbMsgResponse){
+      GWEN_DB_NODE *dbRes;
+
+      dbRes=GWEN_DB_FindFirstGroup(dbMsgResponse, "result");
+      while(dbRes){
+        int code;
+
+        code=GWEN_DB_GetIntValue(dbRes, "resultCode", 0, -1);
+        DBG_DEBUG(AQHBCI_LOGDOMAIN, "Found message result (%d)", code);
+        if (code==3920) {
+          int i;
+          GWEN_TYPE_UINT32 tm=0;
+
+          for (i=0; ; i++) {
+            int j;
+  
+            j=GWEN_DB_GetIntValue(dbRes, "param", i, 0);
+            if (j==0)
+              break;
+            switch(j) {
+            case 999:
+              tm|=AH_USER_TANMETHOD_SINGLE_STEP;
+              break;
+            case 900:
+              tm|=AH_USER_TANMETHOD_TWO_STEP_00;
+              break;
+            case 990:
+              tm|=AH_USER_TANMETHOD_TWO_STEP_0;
+              break;
+            case 991:
+              tm|=AH_USER_TANMETHOD_TWO_STEP_1;
+              break;
+            case 992:
+              tm|=AH_USER_TANMETHOD_TWO_STEP_2;
+              break;
+            case 993:
+              tm|=AH_USER_TANMETHOD_TWO_STEP_3;
+              break;
+            case 994:
+              tm|=AH_USER_TANMETHOD_TWO_STEP_4;
+              break;
+            case 995:
+              tm|=AH_USER_TANMETHOD_TWO_STEP_5;
+              break;
+            case 996:
+              tm|=AH_USER_TANMETHOD_TWO_STEP_6;
+              break;
+            case 997:
+              tm|=AH_USER_TANMETHOD_TWO_STEP_7;
+              break;
+            default:
+              DBG_ERROR(AQHBCI_LOGDOMAIN, "Unknown TAN method %d", j);
+              break;
+            }
+          } /* for */
+          if (i==0) {
+            DBG_ERROR(AQHBCI_LOGDOMAIN,
+                      "Bad server response: No TAN method reported");
+            return -1;
+          }
+          jd->modes=tm;
+        } /* if correct result found */
+
+        dbRes=GWEN_DB_FindNextGroup(dbRes, "result");
+      } /* while result */
+    }
+    dbCurr=GWEN_DB_GetNextGroup(dbCurr);
+  } /* while */
+
+
+  return 0;
+}
+
+
+
+GWEN_TYPE_UINT32 AH_Job_GetItanModes_GetModes(const AH_JOB *j){
+  AH_JOB_GETITANMODES *jd;
+
+  assert(j);
+  jd=GWEN_INHERIT_GETDATA(AH_JOB, AH_JOB_GETITANMODES, j);
+  assert(jd);
+
+  return jd->modes;
+}
+
+
+
+/* __________________________________________________________________________
+ * AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
+ *                             AH_Job_ChangePin
+ * YYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYY
+ */
+
+
+
+/* --------------------------------------------------------------- FUNCTION */
+AH_JOB *AH_Job_ChangePin_new(AB_USER *u, const char *newPin){
+  AH_JOB *j;
+  GWEN_DB_NODE *dbArgs;
+
+  assert(u);
+  j=AH_Job_new("JobChangePin", u, 0);
+  if (!j) {
+    DBG_ERROR(AQHBCI_LOGDOMAIN, "JobChangePin not supported, should not happen");
+    return 0;
+  }
+
+  /* set arguments */
+  dbArgs=AH_Job_GetArguments(j);
+  assert(dbArgs);
+
+  GWEN_DB_SetCharValue(dbArgs, GWEN_DB_FLAGS_OVERWRITE_VARS,
+                       "newPin", newPin);
+
+  DBG_INFO(AQHBCI_LOGDOMAIN, "JobChangePin created");
+  return j;
+}
 
 
 
