@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: adminjobs_p.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: adminjobs_p.h,v 1.4 2006/02/22 19:38:58 aquamaniac Exp $
+    cvs         : $Id: adminjobs_p.h 1042 2006-07-04 01:15:33Z martin $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -123,6 +123,41 @@ static int AH_Job_GetStatus_Exchange(AH_JOB *j, AB_JOB *bj,
 
 
 
+/* __________________________________________________________________________
+ * AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
+ *                             AH_Job_Tan
+ * YYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYY
+ */
+typedef struct AH_JOB_TAN AH_JOB_TAN;
+struct AH_JOB_TAN {
+  char *challenge;
+  char *reference;
+};
+static void AH_Job_Tan_FreeData(void *bp, void *p);
+static int AH_Job_Tan_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx);
+static int AH_Job_Tan_Exchange(AH_JOB *j, AB_JOB *bj,
+                               AH_JOB_EXCHANGE_MODE m);
+
+
+
+/* __________________________________________________________________________
+ * AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
+ *                             AH_Job_GetItanModes
+ * YYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYY
+ */
+typedef struct AH_JOB_GETITANMODES AH_JOB_GETITANMODES;
+struct AH_JOB_GETITANMODES {
+  GWEN_TYPE_UINT32 modes;
+};
+static void AH_Job_GetItanModes_FreeData(void *bp, void *p);
+static int AH_Job_GetItanModes_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx);
+
+
+
+
+
+
+
 #endif /* AH_ADMINJOBS_P_H */
 
 
