@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: outbox.c,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: outbox.c,v 1.9 2006/02/22 19:38:58 aquamaniac Exp $
+    cvs         : $Id: outbox.c 1069 2006-09-29 12:48:25Z martin $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -28,6 +28,7 @@
 #include <aqhbci/provider.h>
 #include <aqbanking/job_be.h>
 #include <aqbanking/banking_be.h>
+#include <aqbanking/imexporter.h>
 #include <gwenhywfar/debug.h>
 #include <gwenhywfar/misc.h>
 #include <gwenhywfar/waitcallback.h>
@@ -727,6 +728,9 @@ int AH_Outbox__CBox_RecvQueue(AH_OUTBOX__CBOX *cbox,
     return AB_ERROR_GENERIC;
   }
 
+  /* transform from ISO 8859-1 to UTF8 */
+  AB_ImExporter_DbFromIso8859_1ToUtf8(rsp);
+
   /* check for message reference */
   if (AH_Msg_GetMsgRef(msg)==0) {
     DBG_ERROR(AQHBCI_LOGDOMAIN, "Unrequested message, deleting it");
@@ -774,19 +778,32 @@ int AH_Outbox__CBox_SendAndRecvQueue(AH_OUTBOX__CBOX *cbox,
 				     AH_JOBQUEUE *jq){
   int rv;
 
-  rv=AH_Outbox__CBox_SendQueue(cbox, timeout, dlg, jq);
-  if (rv) {
-    DBG_INFO(AQHBCI_LOGDOMAIN, "Error sending queue");
-    return rv;
+  if ((AH_JobQueue_GetFlags(jq) & AH_JOBQUEUE_FLAGS_NEEDTAN) &&
+      AH_Dialog_GetItanProcessType(dlg)!=0) {
+    DBG_DEBUG(AQHBCI_LOGDOMAIN, "iTAN mode");
+
+    rv=AH_Outbox__CBox_Itan(cbox, dlg, jq, timeout);
+    if (rv) {
+      DBG_INFO(AQHBCI_LOGDOMAIN, "here (%d)", rv);
+      return rv;
+    }
   }
+  else {
+    DBG_DEBUG(AQHBCI_LOGDOMAIN, "Normal mode");
+    rv=AH_Outbox__CBox_SendQueue(cbox, timeout, dlg, jq);
+    if (rv) {
+      DBG_INFO(AQHBCI_LOGDOMAIN, "Error sending queue");
+      return rv;
+    }
 
-  AH_JobQueue_SetJobStatusOnMatch(jq, AH_JobStatusEncoded,
-				  AH_JobStatusSent);
+    AH_JobQueue_SetJobStatusOnMatch(jq, AH_JobStatusEncoded,
+                                    AH_JobStatusSent);
 
-  rv=AH_Outbox__CBox_RecvQueue(cbox, timeout, dlg, jq);
-  if (rv) {
-    DBG_INFO(AQHBCI_LOGDOMAIN, "Error receiving queue response");
-    return rv;
+    rv=AH_Outbox__CBox_RecvQueue(cbox, timeout, dlg, jq);
+    if (rv) {
+      DBG_INFO(AQHBCI_LOGDOMAIN, "Error receiving queue response");
+      return rv;
+    }
   }
 
   return 0;
@@ -803,11 +820,13 @@ int AH_Outbox__CBox_OpenDialog(AH_OUTBOX__CBOX *cbox, int timeout,
   int rv;
 
   DBG_NOTICE(AQHBCI_LOGDOMAIN, "Creating dialog open request");
+  AH_Dialog_SetItanProcessType(dlg, 0);
+
   if ((jqFlags & AH_JOBQUEUE_FLAGS_CRYPT) ||
       (jqFlags & AH_JOBQUEUE_FLAGS_SIGN)) {
     /* sign and crypt, not anonymous */
     DBG_NOTICE(AQHBCI_LOGDOMAIN,
-	       "Creating non-anonymous dialog open request");
+               "Creating non-anonymous dialog open request");
     jDlgOpen=AH_Job_new("JobDialogInit", cbox->user, 0);
     if (!jDlgOpen) {
       DBG_ERROR(AQHBCI_LOGDOMAIN, "Could not create job JobDialogInit");
@@ -817,6 +836,23 @@ int AH_Outbox__CBox_OpenDialog(AH_OUTBOX__CBOX *cbox, int timeout,
       AH_Job_AddSigner(jDlgOpen,
                        AB_User_GetUserId(cbox->user));
     AH_Dialog_SubFlags(dlg, AH_DIALOG_FLAGS_ANONYMOUS);
+
+    if (AH_User_GetCryptMode(cbox->user)==AH_CryptMode_Pintan) {
+      GWEN_TYPE_UINT32 tm;
+
+      tm=AH_User_GetTanMethods(cbox->user);
+      if ((tm & ~AH_USER_TANMETHOD_SINGLE_STEP) &&
+          !(jqFlags & AH_JOBQUEUE_FLAGS_NOITAN)){
+        /* only use itan if any other mode than singleStep is available
+         * and the job queue does not request non-ITAN mode
+         */
+        rv=AH_Outbox__CBox_SelectItanMode(cbox, dlg);
+        if (rv) {
+          DBG_INFO(AQHBCI_LOGDOMAIN, "here (%d)", rv);
+          return rv;
+        }
+      }
+    }
   }
   else {
     /* neither sign nor crypt, use anonymous dialog */
@@ -851,9 +887,23 @@ int AH_Outbox__CBox_OpenDialog(AH_OUTBOX__CBOX *cbox, int timeout,
     return rv;
   }
   if (AH_Job_HasErrors(jDlgOpen)) {
-    DBG_ERROR(AQHBCI_LOGDOMAIN, "Error opening dialog, aborting");
-    AH_JobQueue_free(jqDlgOpen);
-    return AB_ERROR_GENERIC;
+    /* TODO: check for iTAN related error and try again */
+    if (AH_Job_HasItanResult(jDlgOpen)) {
+      DBG_NOTICE(AQHBCI_LOGDOMAIN,
+		 "Adjusting to iTAN modes of the server");
+      AB_Banking_ProgressLog(AH_HBCI_GetBankingApi(cbox->hbci),
+			     0,
+			     AB_Banking_LogLevelNotice,
+			     I18N("Adjusting to iTAN modes of the server"));
+      rv=AH_Job_CommitSystemData(jDlgOpen);
+      AH_JobQueue_free(jqDlgOpen);
+      return 1;
+    }
+    else {
+      DBG_ERROR(AQHBCI_LOGDOMAIN, "Error opening dialog, aborting");
+      AH_JobQueue_free(jqDlgOpen);
+      return AB_ERROR_GENERIC;
+    }
   }
   DBG_NOTICE(AQHBCI_LOGDOMAIN, "Dialog open request done");
   rv=AH_Job_CommitSystemData(jDlgOpen);
@@ -978,7 +1028,8 @@ int AH_Outbox__CBox_PerformQueue(AH_OUTBOX__CBOX *cbox,
     jqFlags=AH_JobQueue_GetFlags(jq);
     jqFlags&=~(AH_JOBQUEUE_FLAGS_CRYPT |
                AH_JOBQUEUE_FLAGS_SIGN |
-               AH_JOBQUEUE_FLAGS_NOSYSID);
+               AH_JOBQUEUE_FLAGS_NOSYSID |
+               AH_JOBQUEUE_FLAGS_NOITAN);
     AH_JobQueue_SetFlags(jqTodo, (jqFlags&AH_JOBQUEUE_FLAGS_COPYMASK));
 
     /* copy todo jobs */
@@ -1072,7 +1123,8 @@ int AH_Outbox__CBox_PerformNonDialogQueues(AH_OUTBOX__CBOX *cbox,
 					   AH_JOBQUEUE_LIST *jql){
   AH_DIALOG *dlg;
   AH_JOBQUEUE *jq;
-  int rv;
+  int rv=0;
+  int i;
   GWEN_TYPE_UINT32 jqflags;
 
   if (AH_JobQueue_List_GetCount(jql)==0) {
@@ -1081,31 +1133,51 @@ int AH_Outbox__CBox_PerformNonDialogQueues(AH_OUTBOX__CBOX *cbox,
     return 0;
   }
 
-  dlg=AH_Dialog_new(cbox->user);
-  rv=AH_Dialog_Connect(dlg, AH_HBCI_GetConnectTimeout(cbox->hbci));
-  if (rv) {
-    DBG_INFO(AQHBCI_LOGDOMAIN,
-             "Could not begin a dialog for customer \"%s\" (%d)",
-             AB_User_GetCustomerId(cbox->user), rv);
-    /* finish all queues */
-    AH_Outbox__CBox_HandleQueueListError(cbox, jql,
-                                         "Could not begin dialog");
-    AH_Dialog_free(dlg);
-    return rv;
+  for(i=0; i<2; i++) {
+    dlg=AH_Dialog_new(cbox->user);
+    rv=AH_Dialog_Connect(dlg, AH_HBCI_GetConnectTimeout(cbox->hbci));
+    if (rv) {
+      DBG_INFO(AQHBCI_LOGDOMAIN,
+	       "Could not begin a dialog for customer \"%s\" (%d)",
+	       AB_User_GetCustomerId(cbox->user), rv);
+      /* finish all queues */
+      AH_Outbox__CBox_HandleQueueListError(cbox, jql,
+					   "Could not begin dialog");
+      AH_Dialog_free(dlg);
+      return rv;
+    }
+    assert(dlg);
+  
+    jq=AH_JobQueue_List_First(jql);
+    jqflags=AH_JobQueue_GetFlags(jq);
+  
+    /* open dialog */
+    rv=AH_Outbox__CBox_OpenDialog(cbox, timeout, dlg, jqflags);
+    if (rv==0)
+      break;
+    else if (rv<0) {
+      DBG_INFO(AQHBCI_LOGDOMAIN, "Could not open dialog");
+      AH_Dialog_Disconnect(dlg, 2);
+      /* finish all queues */
+      AH_Outbox__CBox_HandleQueueListError(cbox, jql,
+					   "Could not open dialog");
+      AH_Dialog_free(dlg);
+      return rv;
+    }
+    else if (rv==1) {
+      AH_Dialog_Disconnect(dlg, 2);
+      AB_Banking_ProgressLog(AH_HBCI_GetBankingApi(cbox->hbci),
+			     0,
+			     AB_Banking_LogLevelInfo,
+			     I18N("Retrying to open dialog"));
+    }
   }
-  assert(dlg);
-
-  jq=AH_JobQueue_List_First(jql);
-  jqflags=AH_JobQueue_GetFlags(jq);
-
-  /* open dialog */
-  rv=AH_Outbox__CBox_OpenDialog(cbox, timeout, dlg, jqflags);
   if (rv) {
     DBG_INFO(AQHBCI_LOGDOMAIN, "Could not open dialog");
     AH_Dialog_Disconnect(dlg, 2);
     /* finish all queues */
     AH_Outbox__CBox_HandleQueueListError(cbox, jql,
-                                         "Could not open dialog");
+					 "Could not open dialog");
     AH_Dialog_free(dlg);
     return rv;
   }
@@ -1168,6 +1240,16 @@ int AH_Outbox__CBox_PerformDialogQueue(AH_OUTBOX__CBOX *cbox,
   }
   assert(dlg);
 
+  /* select iTAN mode */
+  if (!(AH_JobQueue_GetFlags(jq) & AH_JOBQUEUE_FLAGS_NOITAN)) {
+    rv=AH_Outbox__CBox_SelectItanMode(cbox, dlg);
+    if (rv) {
+      AH_Dialog_Disconnect(dlg, 2);
+      AH_Dialog_free(dlg);
+      return rv;
+    }
+  }
+
   /* handle queue */
   rv=AH_Outbox__CBox_PerformQueue(cbox, dlg, jq, timeout);
   if (rv) {
@@ -1985,6 +2067,9 @@ AH_JOB *AH_Outbox_FindTransferJob(AH_OUTBOX *ob,
 
 
 
+#include "itan.inc"
+#include "itan1.inc"
+#include "itan2.inc"
 
 
 
