@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: aqhbci.c,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: aqhbci.c,v 1.1 2006/02/22 19:38:55 aquamaniac Exp $
+    cvs         : $Id: aqhbci.c 950 2006-02-22 19:39:02Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
