@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: provider.c,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: provider.c,v 1.14 2006/03/07 01:34:24 aquamaniac Exp $
+    cvs         : $Id: provider.c 1071 2006-09-30 11:05:50Z martin $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -638,7 +638,7 @@ int AH_Provider_AddJob(AB_PROVIDER *pro, AB_JOB *j){
 	AB_Banking_ProgressLog(AH_HBCI_GetBankingApi(hp->hbci),
 			       0,
 			       AB_Banking_LogLevelError,
-			       "ERROR: Multiple signatures not yet supported");
+			       I18N("ERROR: Multiple signatures not yet supported"));
 	return AB_ERROR_GENERIC;
       }
       AH_Job_AddSigner(mj, AB_User_GetUserId(mu));
@@ -994,6 +994,7 @@ int AH_Provider_GetSysId(AB_PROVIDER *pro, AB_USER *u,
   int rv;
   AH_PROVIDER *hp;
   const char *s;
+  int i;
 
   assert(pro);
   hp=GWEN_INHERIT_GETDATA(AB_PROVIDER, AH_PROVIDER, pro);
@@ -1009,41 +1010,74 @@ int AH_Provider_GetSysId(AB_PROVIDER *pro, AB_USER *u,
   h=AH_Provider_GetHbci(pro);
   assert(h);
 
-  job=AH_Job_GetSysId_new(u);
-  if (!job) {
-    DBG_ERROR(0, "Job not supported, should not happen");
-    return AB_ERROR_GENERIC;
-  }
-  AH_Job_AddSigner(job, AB_User_GetUserId(u));
+  job=0;
+  ob=0;
+  rv=0;
+  for (i=0; ; i++) {
+    job=AH_Job_GetSysId_new(u);
+    if (!job) {
+      DBG_ERROR(0, "Job not supported, should not happen");
+      return AB_ERROR_GENERIC;
+    }
+    AH_Job_AddSigner(job, AB_User_GetUserId(u));
 
-  ob=AH_Outbox_new(h);
-  AH_Outbox_AddJob(ob, job);
+    ob=AH_Outbox_new(h);
+    AH_Outbox_AddJob(ob, job);
 
-  rv=AH_Outbox_Execute(ob, ctx, 0, 1);
-  if (rv) {
-    DBG_ERROR(0, "Could not execute outbox.\n");
-    if (!nounmount)
-      AH_Medium_Unmount(m, 1);
-    return rv;
-  }
-
-  if (AH_Job_HasErrors(job)) {
-    DBG_ERROR(AQHBCI_LOGDOMAIN, "Job has errors");
-    // TODO: show errors
-    AH_Outbox_free(ob);
-    if (!nounmount)
-      AH_Medium_Unmount(m, 1);
-    return AB_ERROR_GENERIC;
-  }
-  else {
-    rv=AH_Job_Commit(job);
+    rv=AH_Outbox_Execute(ob, ctx, 0, 1);
     if (rv) {
-      DBG_ERROR(AQHBCI_LOGDOMAIN, "Could not commit result.\n");
-      AH_Outbox_free(ob);
+      DBG_ERROR(0, "Could not execute outbox.\n");
       if (!nounmount)
         AH_Medium_Unmount(m, 1);
       return rv;
     }
+
+    if (AH_Job_HasErrors(job)) {
+      if (AH_Job_HasItanResult(job)) {
+        AB_Banking_ProgressLog(ab, 0, AB_Banking_LogLevelError,
+                               I18N("Adjusting to iTAN modes of the server"));
+        rv=AH_Job_Commit(job);
+        if (rv) {
+          DBG_ERROR(AQHBCI_LOGDOMAIN, "Could not commit result.\n");
+          AH_Outbox_free(ob);
+          if (!nounmount)
+            AH_Medium_Unmount(m, 1);
+          return rv;
+        }
+
+        AB_Banking_ProgressLog(ab, 0, AB_Banking_LogLevelError,
+                               I18N("Retrying to get system id."));
+      }
+      else {
+        DBG_ERROR(AQHBCI_LOGDOMAIN, "Job has errors");
+        // TODO: show errors
+        AH_Outbox_free(ob);
+        if (!nounmount)
+          AH_Medium_Unmount(m, 1);
+        return AB_ERROR_GENERIC;
+      }
+    }
+    else {
+      rv=AH_Job_Commit(job);
+      if (rv) {
+        DBG_ERROR(AQHBCI_LOGDOMAIN, "Could not commit result.\n");
+        AH_Outbox_free(ob);
+        if (!nounmount)
+          AH_Medium_Unmount(m, 1);
+        return rv;
+      }
+      break;
+    }
+    AH_Job_free(job);
+    AH_Outbox_free(ob);
+    if (i>1) {
+      DBG_ERROR(AQHBCI_LOGDOMAIN, "Tried too often, giving up");
+      AB_Banking_ProgressLog(ab, 0, AB_Banking_LogLevelError,
+                             I18N("Could not get system id after multiple trials"));
+      if (!nounmount)
+        AH_Medium_Unmount(m, 1);
+      return AB_ERROR_GENERIC;
+    }
   }
 
   s=AH_Job_GetSysId_GetSysId(job);
@@ -1155,7 +1189,7 @@ int AH_Provider_GetServerKeys(AB_PROVIDER *pro, AB_USER *u,
   }
 
   AB_Banking_ProgressLog(ab, 0, AB_Banking_LogLevelNotice,
-                         I18N("Keys saved"));
+                         I18N("Keys saved."));
 
   AH_Outbox_free(ob);
 
@@ -1222,9 +1256,9 @@ int AH_Provider_SendUserKeys(AB_PROVIDER *pro, AB_USER *u,
   signKey=AH_Medium_GetLocalPubSignKey(m);
   cryptKey=AH_Medium_GetLocalPubCryptKey(m);
   if (!signKey || !cryptKey) {
-    DBG_ERROR(0, "Either sign- or crypt key missing");
+    DBG_ERROR(0, "Either sign key or crypt key missing");
     AB_Banking_ProgressLog(ab, 0, AB_Banking_LogLevelError,
-                           I18N("Either sign- or crypt key missing"));
+                           I18N("Either sign key or crypt key missing"));
     GWEN_CryptKey_free(signKey);
     GWEN_CryptKey_free(cryptKey);
     if (!nounmount && mounted)
@@ -1339,6 +1373,188 @@ int AH_Provider_GetCert(AB_PROVIDER *pro, AB_USER *u, int nounmount) {
 
 
 
+int AH_Provider_GetItanModes(AB_PROVIDER *pro, AB_USER *u,
+                             AB_IMEXPORTER_CONTEXT *ctx,
+                             int nounmount) {
+  AB_BANKING *ab;
+  AH_HBCI *h;
+  AH_MEDIUM *m;
+  AH_JOB *job;
+  AH_OUTBOX *ob;
+  int rv;
+  AH_PROVIDER *hp;
+  GWEN_TYPE_UINT32 tm=0;
+
+  assert(pro);
+  hp=GWEN_INHERIT_GETDATA(AB_PROVIDER, AH_PROVIDER, pro);
+  assert(hp);
+
+  assert(u);
+  m=AH_User_GetMedium(u);
+  assert(m);
+
+  ab=AB_Provider_GetBanking(pro);
+  assert(ab);
+
+  h=AH_Provider_GetHbci(pro);
+  assert(h);
+
+  job=AH_Job_GetItanModes_new(u);
+  if (!job) {
+    DBG_ERROR(0, "Job not supported, should not happen");
+    return AB_ERROR_GENERIC;
+  }
+  AH_Job_AddSigner(job, AB_User_GetUserId(u));
+
+  ob=AH_Outbox_new(h);
+  AH_Outbox_AddJob(ob, job);
+
+  rv=AH_Outbox_Execute(ob, ctx, 0, 1);
+  if (rv) {
+    DBG_ERROR(0, "Could not execute outbox.\n");
+    if (!nounmount)
+      AH_Medium_Unmount(m, 1);
+    return rv;
+  }
+
+  tm=AH_Job_GetItanModes_GetModes(job);
+  if (!tm) {
+    DBG_ERROR(AQHBCI_LOGDOMAIN, "No iTAN modes reported");
+    AB_Banking_ProgressLog(AB_Provider_GetBanking(pro),
+                           0,
+                           AB_Banking_LogLevelError,
+                           I18N("No iTAN modes reported."));
+    AH_Outbox_free(ob);
+    if (!nounmount)
+      AH_Medium_Unmount(m, 1);
+    return AB_ERROR_NO_DATA;
+  }
+
+  /* we have received tan methods, so there was a 3920 response. In this
+   * special case we need to apply the job data, because otherwise we couldn't
+   * fully connect to the server next time.
+   */
+  rv=AH_Job_Commit(job);
+  if (rv) {
+    DBG_ERROR(AQHBCI_LOGDOMAIN, "Could not commit result.\n");
+    AB_Banking_ProgressLog(AB_Provider_GetBanking(pro),
+                           0,
+                           AB_Banking_LogLevelError,
+                           I18N("Could not commit result to the system"));
+    AH_Outbox_free(ob);
+    if (!nounmount)
+      AH_Medium_Unmount(m, 1);
+    return rv;
+  }
+
+  /* set TAN methods */
+  AB_Banking_ProgressLog(AB_Provider_GetBanking(pro),
+                         0,
+                         AB_Banking_LogLevelNotice,
+                         I18N("Retrieved iTAN modes, storing."));
+  AH_User_SetTanMethods(u, tm);
+
+  AH_Outbox_free(ob);
+
+  if (!nounmount)
+    AH_Medium_Unmount(m, 1);
+
+  return 0;
+}
+
+
+
+int AH_Provider_ChangePin(AB_PROVIDER *pro, AB_USER *u,
+                          AB_IMEXPORTER_CONTEXT *ctx,
+                          int nounmount) {
+  AB_BANKING *ab;
+  AH_HBCI *h;
+  AH_MEDIUM *m;
+  AH_JOB *job;
+  AH_OUTBOX *ob;
+  int rv;
+  AH_PROVIDER *hp;
+  char pwbuf[32];
+
+  assert(pro);
+  hp=GWEN_INHERIT_GETDATA(AB_PROVIDER, AH_PROVIDER, pro);
+  assert(hp);
+
+  assert(u);
+  m=AH_User_GetMedium(u);
+  assert(m);
+
+  ab=AB_Provider_GetBanking(pro);
+  assert(ab);
+
+  h=AH_Provider_GetHbci(pro);
+  assert(h);
+
+  memset(pwbuf, 0, sizeof(pwbuf));
+  rv=AB_Banking_InputBox(ab,
+                         AB_BANKING_INPUT_FLAGS_NUMERIC |
+                         AB_BANKING_INPUT_FLAGS_CONFIRM,
+                         I18N("Enter New Banking PIN"),
+                         I18N("Please enter a new banking PIN.\n"
+                              "You must only enter numbers, not letters.\n"
+                              "<html>"
+                              "<p>"
+                              "Please enter a new banking PIN."
+                              "</p>"
+                              "<p>"
+                              "You must only enter numbers, not letters."
+                              "</p>"
+                              "</html>"),
+                         pwbuf,
+                         0, 8);
+
+  job=AH_Job_ChangePin_new(u, pwbuf);
+  if (!job) {
+    DBG_ERROR(0, "Job not supported, should not happen");
+    return AB_ERROR_GENERIC;
+  }
+  AH_Job_AddSigner(job, AB_User_GetUserId(u));
+
+  ob=AH_Outbox_new(h);
+  AH_Outbox_AddJob(ob, job);
+
+  rv=AH_Outbox_Execute(ob, ctx, 0, 1);
+  if (rv) {
+    DBG_ERROR(0, "Could not execute outbox.\n");
+    if (!nounmount)
+      AH_Medium_Unmount(m, 1);
+    return rv;
+  }
+
+  if (AH_Job_HasErrors(job)) {
+    DBG_ERROR(AQHBCI_LOGDOMAIN, "Job has errors");
+    // TODO: show errors
+    AH_Outbox_free(ob);
+    if (!nounmount)
+      AH_Medium_Unmount(m, 1);
+    return AB_ERROR_GENERIC;
+  }
+  else {
+    rv=AH_Job_Commit(job);
+    if (rv) {
+      DBG_ERROR(AQHBCI_LOGDOMAIN, "Could not commit result.\n");
+      AH_Outbox_free(ob);
+      if (!nounmount)
+        AH_Medium_Unmount(m, 1);
+      return rv;
+    }
+  }
+
+  AH_Outbox_free(ob);
+
+  if (!nounmount)
+    AH_Medium_Unmount(m, 1);
+
+  return 0;
+}
+
+
+
 int AH_Provider_GetIniLetterTxt(AB_PROVIDER *pro,
                                 AB_USER *u,
                                 int useBankKey,
@@ -1452,7 +1668,7 @@ int AH_Provider_GetIniLetterTxt(AB_PROVIDER *pro,
 
   if (useBankKey) {
     GWEN_Buffer_AppendString(lbuf,
-                             I18N("Bank           : "));
+                             I18N("Bank Code      : "));
     GWEN_Buffer_AppendString(lbuf, AB_User_GetBankCode(u));
   }
   else {
@@ -1594,7 +1810,7 @@ int AH_Provider_GetIniLetterTxt(AB_PROVIDER *pro,
   if (!useBankKey) {
     GWEN_Buffer_AppendString(lbuf, "\n\n");
     GWEN_Buffer_AppendString(lbuf,
-                             I18N("I confirm that I found the above key "
+                             I18N("I confirm that I created the above key "
                                   "for my electronic signature.\n"));
     GWEN_Buffer_AppendString(lbuf, "\n\n");
     GWEN_Buffer_AppendString(lbuf,
@@ -1723,7 +1939,7 @@ int AH_Provider_GetIniLetterHtml(AB_PROVIDER *pro,
 
   if (useBankKey) {
     GWEN_Buffer_AppendString(lbuf, "<tr><td>\n");
-    GWEN_Buffer_AppendString(lbuf, I18N("Bank"));
+    GWEN_Buffer_AppendString(lbuf, I18N("Bank Code"));
     GWEN_Buffer_AppendString(lbuf, "</td><td>\n");
     GWEN_Buffer_AppendString(lbuf, AB_User_GetBankCode(u));
     GWEN_Buffer_AppendString(lbuf, "</td></tr>\n");
@@ -1875,7 +2091,7 @@ int AH_Provider_GetIniLetterHtml(AB_PROVIDER *pro,
   if (!useBankKey) {
     GWEN_Buffer_AppendString(lbuf, "<br><br>\n");
     GWEN_Buffer_AppendString(lbuf,
-                             I18N("I confirm that I found the above key "
+                             I18N("I confirm that I created the above key "
                                   "for my electronic signature.\n"));
     GWEN_Buffer_AppendString(lbuf, "<br><br>\n");
     GWEN_Buffer_AppendString(lbuf, "<table>\n");
