@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: provider_p.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: provider_p.h,v 1.5 2006/02/22 19:38:59 aquamaniac Exp $
+    cvs         : $Id: provider_p.h 950 2006-02-22 19:39:02Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
