@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: job.c,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: job.c,v 1.6 2006/02/14 02:11:55 aquamaniac Exp $
+    cvs         : $Id: job.c 1051 2006-07-18 12:01:39Z martin $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -53,6 +53,7 @@ AH_JOB *AH_Job_new(const char *name,
   int needsBPD;
   int needTAN;
   int noSysId;
+  int noItan;
   GWEN_DB_NODE *bpdgrp;
   const AH_BPD *bpd;
   GWEN_MSGENGINE *e;
@@ -113,6 +114,7 @@ AH_JOB *AH_Job_new(const char *name,
   needsBPD=(atoi(GWEN_XMLNode_GetProperty(node, "needbpd", "0"))!=0);
   needTAN=(atoi(GWEN_XMLNode_GetProperty(node, "needtan", "0"))!=0);
   noSysId=(atoi(GWEN_XMLNode_GetProperty(node, "nosysid", "0"))!=0);
+  noItan=(atoi(GWEN_XMLNode_GetProperty(node, "noitan", "0"))!=0);
   paramName=GWEN_XMLNode_GetProperty(node, "params", "");
   segCode=GWEN_XMLNode_GetProperty(node, "code", "");
 
@@ -262,6 +264,10 @@ AH_JOB *AH_Job_new(const char *name,
     j->flags|=AH_JOB_FLAGS_SINGLE;
   }
 
+  if (noItan) {
+    j->flags|=AH_JOB_FLAGS_NOITAN;
+  }
+
   /* get description */
   descrNode=GWEN_XMLNode_FindFirstTag(jobNode, "DESCR", 0, 0);
   if (descrNode) {
@@ -304,6 +310,9 @@ AH_JOB *AH_Job_new(const char *name,
       j->flags|=(AH_JOB_FLAGS_NEEDCRYPT| AH_JOB_FLAGS_CRYPT);
     if (atoi(GWEN_XMLNode_GetProperty(msgNode, "nosysid", "0"))!=0)
       j->flags|=AH_JOB_FLAGS_NOSYSID;
+    if (atoi(GWEN_XMLNode_GetProperty(msgNode, "noitan", "0"))!=0) {
+      j->flags|=AH_JOB_FLAGS_NOITAN;
+    }
   } /* if msgNode */
   else {
     DBG_INFO(AQHBCI_LOGDOMAIN, "Single message job");
@@ -444,6 +453,12 @@ int AH_Job_PrepareNextMessage(AH_JOB *j) {
     else
       j->flags&=~AH_JOB_FLAGS_NOSYSID;
 
+    if (atoi(GWEN_XMLNode_GetProperty(j->msgNode, "noitan", "0"))!=0) {
+      j->flags|=AH_JOB_FLAGS_NOITAN;
+    }
+    else
+      j->flags&=~AH_JOB_FLAGS_NOITAN;
+
     j->flags|=AH_JOB_FLAGS_HASMOREMSGS;
     return 1;
   }
@@ -954,7 +969,7 @@ void AH_Job_SampleResults(AH_JOB *j) {
 
             if (code>=9000)
               ll=AB_Banking_LogLevelError;
-            else if (code>=3000)
+            else if (code>=3000 && code!=3920)
               ll=AB_Banking_LogLevelWarn;
             else
               ll=AB_Banking_LogLevelInfo;
@@ -971,6 +986,7 @@ void AH_Job_SampleResults(AH_JOB *j) {
                        GWEN_Buffer_GetStart(lbuf));
             GWEN_Buffer_free(lbuf);
           }
+
           /* found a result */
           r=AH_Result_new(code,
                           text,
@@ -1142,7 +1158,7 @@ int AH_Job_CommitSystemData(AH_JOB *j) {
     }
     if (dbRd) {
       DBG_NOTICE(AQHBCI_LOGDOMAIN,
-		 "Checking group \"%s\"", GWEN_DB_GroupName(dbRd));
+                 "Checking group \"%s\"", GWEN_DB_GroupName(dbRd));
       if (strcasecmp(GWEN_DB_GroupName(dbRd), "bpd")==0){
         AH_BPD *bpd;
         GWEN_DB_NODE *n;
@@ -1157,14 +1173,8 @@ int AH_Job_CommitSystemData(AH_JOB *j) {
 
         /* read bank name */
         p=GWEN_DB_GetCharValue(dbRd, "name", 0, 0);
-        if (p) {
-	  GWEN_BUFFER *xbuf;
-
-	  xbuf=GWEN_Buffer_new(0, 32, 0, 1);
-	  AH_HBCI_HbciToUtf8(p, 0, xbuf);
-	  AH_Bpd_SetBankName(bpd, GWEN_Buffer_GetStart(xbuf));
-          GWEN_Buffer_free(xbuf);
-        }
+        if (p)
+          AH_Bpd_SetBankName(bpd, p);
         AH_Bpd_SetJobTypesPerMsg(bpd,
                                  GWEN_DB_GetIntValue(dbRd,
                                                      "jobtypespermsg",
@@ -1293,6 +1303,80 @@ int AH_Job_CommitSystemData(AH_JOB *j) {
         modCust=1;
       } /* if PIN/TAN extension found */
 
+      else if (strcasecmp(GWEN_DB_GroupName(dbRd), "SegResult")==0){
+        GWEN_DB_NODE *dbRes;
+
+        dbRes=GWEN_DB_GetFirstGroup(dbRd);
+        while(dbRes) {
+          if (strcasecmp(GWEN_DB_GroupName(dbRes), "result")==0) {
+            int code;
+            const char *text;
+  
+            code=GWEN_DB_GetIntValue(dbRes, "resultcode", 0, 0);
+            text=GWEN_DB_GetCharValue(dbRes, "text", 0, 0);
+            if (code==3920) {
+              int i;
+
+              AH_User_SetTanMethods(u, 0);
+              for (i=0; ; i++) {
+                int j;
+
+                j=GWEN_DB_GetIntValue(dbRes, "param", i, 0);
+                if (j==0)
+                  break;
+                switch(j) {
+                case 999:
+                  DBG_INFO(AQHBCI_LOGDOMAIN, "Adding tan method %d", j);
+                  AH_User_AddTanMethods(u, AH_USER_TANMETHOD_SINGLE_STEP);
+                  break;
+                case 900:
+                  DBG_INFO(AQHBCI_LOGDOMAIN, "Adding tan method %d", j);
+                  AH_User_AddTanMethods(u, AH_USER_TANMETHOD_TWO_STEP_00);
+                  break;
+                case 990:
+                  DBG_INFO(AQHBCI_LOGDOMAIN, "Adding tan method %d", j);
+                  AH_User_AddTanMethods(u, AH_USER_TANMETHOD_TWO_STEP_0);
+                  break;
+                case 991:
+                  DBG_INFO(AQHBCI_LOGDOMAIN, "Adding tan method %d", j);
+                  AH_User_AddTanMethods(u, AH_USER_TANMETHOD_TWO_STEP_1);
+                  break;
+                case 992:
+                  DBG_INFO(AQHBCI_LOGDOMAIN, "Adding tan method %d", j);
+                  AH_User_AddTanMethods(u, AH_USER_TANMETHOD_TWO_STEP_2);
+                  break;
+                case 993:
+                  DBG_INFO(AQHBCI_LOGDOMAIN, "Adding tan method %d", j);
+                  AH_User_AddTanMethods(u, AH_USER_TANMETHOD_TWO_STEP_3);
+                  break;
+                case 994:
+                  DBG_INFO(AQHBCI_LOGDOMAIN, "Adding tan method %d", j);
+                  AH_User_AddTanMethods(u, AH_USER_TANMETHOD_TWO_STEP_4);
+                  break;
+                case 995:
+                  DBG_INFO(AQHBCI_LOGDOMAIN, "Adding tan method %d", j);
+                  AH_User_AddTanMethods(u, AH_USER_TANMETHOD_TWO_STEP_5);
+                  break;
+                case 996:
+                  DBG_INFO(AQHBCI_LOGDOMAIN, "Adding tan method %d", j);
+                  AH_User_AddTanMethods(u, AH_USER_TANMETHOD_TWO_STEP_6);
+                  break;
+                case 997:
+                  DBG_INFO(AQHBCI_LOGDOMAIN, "Adding tan method %d", j);
+                  AH_User_AddTanMethods(u, AH_USER_TANMETHOD_TWO_STEP_7);
+                  break;
+                default:
+                  DBG_ERROR(AQHBCI_LOGDOMAIN, "Unknown TAN method %d", j);
+                  break;
+                }
+              } /* for */
+              if (i==0)
+                AH_User_AddTanMethods(u, AH_USER_TANMETHOD_SINGLE_STEP);
+            }
+          } /* if result */
+          dbRes=GWEN_DB_GetNextGroup(dbRes);
+        } /* while */
+      }
       else {
         GWEN_XMLNODE *bpdn;
         int segver;
@@ -1321,7 +1405,8 @@ int AH_Job_CommitSystemData(AH_JOB *j) {
             AH_BPD *bpd;
             char numbuffer[32];
 
-            DBG_NOTICE(AQHBCI_LOGDOMAIN, "Found BPD job \"%s\"", GWEN_DB_GroupName(dbRd));
+            DBG_NOTICE(AQHBCI_LOGDOMAIN, "Found BPD job \"%s\"",
+                       GWEN_DB_GroupName(dbRd));
             bpd=AH_User_GetBpd(j->user);
             assert(bpd);
 	    if (!bpdDeleted) {
@@ -1353,9 +1438,10 @@ int AH_Job_CommitSystemData(AH_JOB *j) {
             modCust=1;
           } /* if isbpdjob */
           else {
-            DBG_INFO(AQHBCI_LOGDOMAIN, "Segment \"%s\" is known but not as a BPD job",
-                     GWEN_DB_GroupName(dbRd));
-          }
+	    DBG_INFO(AQHBCI_LOGDOMAIN,
+		     "Segment \"%s\" is known but not as a BPD job",
+		     GWEN_DB_GroupName(dbRd));
+	  }
         } /* if segment found */
         else {
           DBG_WARN(AQHBCI_LOGDOMAIN, "Did not find segment \"%s\" (%d) ignoring",
@@ -1367,9 +1453,9 @@ int AH_Job_CommitSystemData(AH_JOB *j) {
         /* UserData found */
         DBG_NOTICE(AQHBCI_LOGDOMAIN, "Found UserData");
         AH_User_SetUpdVersion(j->user,
-                                  GWEN_DB_GetIntValue(dbRd,
-                                                      "version",
-                                                      0, 0));
+			      GWEN_DB_GetIntValue(dbRd,
+						  "version",
+						  0, 0));
       }
       else if (strcasecmp(GWEN_DB_GroupName(dbRd), "AccountData")==0){
         const char *accountId;
@@ -1396,11 +1482,12 @@ int AH_Job_CommitSystemData(AH_JOB *j) {
         assert(bankCode);
         custId=GWEN_DB_GetCharValue(dbRd, "customer", 0, 0);
         assert(custId);
-        if (1) {
+	if (1) {
           GWEN_BUFFER *mbuf;
 
           mbuf=GWEN_Buffer_new(0, 128, 0, 1);
-          GWEN_Buffer_AppendString(mbuf, "Received account: ");
+          GWEN_Buffer_AppendString(mbuf, I18N("Received account:"));
+	  GWEN_Buffer_AppendString(mbuf, " ");
           GWEN_Buffer_AppendString(mbuf, bankCode);
           GWEN_Buffer_AppendString(mbuf, " / ");
           if (accountName)
@@ -1441,22 +1528,10 @@ int AH_Job_CommitSystemData(AH_JOB *j) {
         }
 
         /* modify account */
-	if (accountName) {
-	  GWEN_BUFFER *xbuf;
-
-	  xbuf=GWEN_Buffer_new(0, 32, 0, 1);
-	  AH_HBCI_HbciToUtf8(accountName, 0, xbuf);
-          AB_Account_SetAccountName(acc, GWEN_Buffer_GetStart(xbuf));
-          GWEN_Buffer_free(xbuf);
-        }
-	if (userName) {
-	  GWEN_BUFFER *xbuf;
-
-	  xbuf=GWEN_Buffer_new(0, 32, 0, 1);
-	  AH_HBCI_HbciToUtf8(userName, 0, xbuf);
-          AB_Account_SetOwnerName(acc, GWEN_Buffer_GetStart(xbuf));
-          GWEN_Buffer_free(xbuf);
-        }
+        if (accountName)
+          AB_Account_SetAccountName(acc, accountName);
+        if (userName)
+          AB_Account_SetOwnerName(acc, userName);
 
         /* set bank name */
         bpd=AH_User_GetBpd(j->user);
@@ -1497,7 +1572,7 @@ int AH_Job_CommitSystemData(AH_JOB *j) {
         AB_Banking_ProgressLog(AH_Job_GetBankingApi(j),
                                0,
                                AB_Banking_LogLevelNotice,
-                               "Bank message received");
+                               I18N("Bank message received"));
         subject=GWEN_DB_GetCharValue(dbRd, "subject", 0, "(Kein Betreff)");
         text=GWEN_DB_GetCharValue(dbRd, "text", 0, 0);
         if (subject && text) {
@@ -1528,6 +1603,48 @@ int AH_Job_CommitSystemData(AH_JOB *j) {
 
 
 
+int AH_Job_HasItanResult(AH_JOB *j) {
+  GWEN_DB_NODE *dbCurr;
+
+  assert(j);
+  assert(j->usage);
+
+  dbCurr=GWEN_DB_GetFirstGroup(j->jobResponses);
+  while(dbCurr) {
+    GWEN_DB_NODE *dbRd;
+
+    dbRd=GWEN_DB_GetGroup(dbCurr, GWEN_PATH_FLAGS_NAMEMUSTEXIST, "data");
+    if (dbRd) {
+      dbRd=GWEN_DB_GetFirstGroup(dbRd);
+    }
+    if (dbRd) {
+      if (strcasecmp(GWEN_DB_GroupName(dbRd), "SegResult")==0){
+        GWEN_DB_NODE *dbRes;
+
+        dbRes=GWEN_DB_GetFirstGroup(dbRd);
+        while(dbRes) {
+          if (strcasecmp(GWEN_DB_GroupName(dbRes), "result")==0) {
+            int code;
+            const char *text;
+  
+            code=GWEN_DB_GetIntValue(dbRes, "resultcode", 0, 0);
+            text=GWEN_DB_GetCharValue(dbRes, "text", 0, 0);
+            if (code==3920) {
+              return 1;
+            }
+          } /* if result */
+          dbRes=GWEN_DB_GetNextGroup(dbRes);
+        } /* while */
+      }
+    } /* if response data found */
+    dbCurr=GWEN_DB_GetNextGroup(dbCurr);
+  } /* while */
+
+  return 0; /* no iTAN response */
+}
+
+
+
 int AH_Job_DefaultProcessHandler(AH_JOB *j){
   assert(j);
   assert(j->usage);
@@ -1734,7 +1851,7 @@ int AH_Job_CheckSignature(AH_JOB *j, GWEN_DB_NODE *dbRsp) {
     AB_Banking_ProgressLog(AH_Job_GetBankingApi(j),
                            0,
                            AB_Banking_LogLevelError,
-                           "Response without security info (internal)");
+                           I18N("Response without security info (internal)"));
     return AB_ERROR_GENERIC;
   }
 
@@ -1751,7 +1868,7 @@ int AH_Job_CheckSignature(AH_JOB *j, GWEN_DB_NODE *dbRsp) {
       AB_Banking_ProgressLog(AH_Job_GetBankingApi(j),
                              0,
                              AB_Banking_LogLevelError,
-                             "Invalid bank signature");
+                             I18N("Invalid bank signature"));
       return AB_ERROR_SECURITY;
     }
   } /* for */
