@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: job_l.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: job_l.h,v 1.4 2006/02/22 19:38:59 aquamaniac Exp $
+    cvs         : $Id: job_l.h 1041 2006-07-03 17:14:56Z martin $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -17,6 +17,7 @@
 typedef struct AH_JOB AH_JOB;
 
 
+#define AH_JOB_FLAGS_NOITAN         0x00002000
 #define AH_JOB_FLAGS_TANUSED        0x00004000
 #define AH_JOB_FLAGS_NOSYSID        0x00008000
 #define AH_JOB_FLAGS_NEEDCRYPT      0x00010000
@@ -153,6 +154,13 @@ int AH_Job_Commit(AH_JOB *j);
 int AH_Job_Exchange(AH_JOB *j, AB_JOB *bj,
                     AH_JOB_EXCHANGE_MODE m);
 
+/**
+ * Check whether the results for this job contain warning 3920. In this
+ * case the result must be commited.
+ * @return 0 if there is no such result, !=0 otherwise
+ */
+int AH_Job_HasItanResult(AH_JOB *j);
+
 
 /**
  * You can use this from the Commit function of the inheriting class to
