@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: jobqueue.c,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: jobqueue.c,v 1.9 2006/02/22 19:38:59 aquamaniac Exp $
+    cvs         : $Id: jobqueue.c 1043 2006-07-04 11:12:59Z martin $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -28,6 +28,7 @@
 #include <gwenhywfar/misc.h>
 #include <gwenhywfar/logger.h>
 #include <gwenhywfar/waitcallback.h>
+#include <gwenhywfar/text.h>
 
 #include <stdlib.h>
 #include <assert.h>
@@ -110,6 +111,7 @@ AH_JOBQUEUE_ADDRESULT AH_JobQueue_AddJob(AH_JOBQUEUE *jq, AH_JOB *j){
   int crypt;
   int needTAN;
   int noSysId;
+  int noItan;
   GWEN_STRINGLIST *jobTypes;
   AH_JOB *cj;
   AH_BPD *bpd;
@@ -135,6 +137,7 @@ AH_JOBQUEUE_ADDRESULT AH_JobQueue_AddJob(AH_JOBQUEUE *jq, AH_JOB *j){
   crypt=0;
   needTAN=0;
   noSysId=0;
+  noItan=0;
   jobTypes=GWEN_StringList_new();
   cj=AH_Job_List_First(jq->jobs);
   while(cj) {
@@ -146,98 +149,108 @@ AH_JOBQUEUE_ADDRESULT AH_JobQueue_AddJob(AH_JOBQUEUE *jq, AH_JOB *j){
                 (AH_Job_GetFlags(cj) & AH_JOB_FLAGS_DLGJOB));
     crypt|=(AH_Job_GetFlags(cj) & AH_JOB_FLAGS_CRYPT);
     needTAN|=(AH_Job_GetFlags(cj) & AH_JOB_FLAGS_NEEDTAN);
-    noSysId|=(AH_Job_GetFlags(cj) & AH_JOBQUEUE_FLAGS_NOSYSID);
+    noSysId|=(AH_Job_GetFlags(cj) & AH_JOB_FLAGS_NOSYSID);
+    noItan|=(AH_Job_GetFlags(cj) & AH_JOB_FLAGS_NOITAN);
     cj=AH_Job_List_Next(cj);
   } /* while */
   jobTypeCount=GWEN_StringList_Count(jobTypes);
   GWEN_StringList_free(jobTypes);
 
-  if (jobCount &&
-      ((crypt!=(AH_Job_GetFlags(j) & AH_JOB_FLAGS_CRYPT) ||
-        (needTAN!=(AH_Job_GetFlags(j) & AH_JOB_FLAGS_NEEDTAN))||
-        (noSysId!=(AH_Job_GetFlags(j) & AH_JOB_FLAGS_NOSYSID))))) {
-    DBG_INFO(AQHBCI_LOGDOMAIN,
-             "Encryption/TAN/SysId flags for queue and this job differ");
-    return AH_JobQueueAddResultJobLimit;
-  }
+  if (strcasecmp(AH_Job_GetName(j), "JobTan")!=0) {
+    if (jobCount &&
+        (
+         (crypt!=(AH_Job_GetFlags(j) & AH_JOB_FLAGS_CRYPT)) ||
+         (needTAN!=(AH_Job_GetFlags(j) & AH_JOB_FLAGS_NEEDTAN)) ||
+         (noSysId!=(AH_Job_GetFlags(j) & AH_JOB_FLAGS_NOSYSID)) ||
+         (noItan!=(AH_Job_GetFlags(j) & AH_JOB_FLAGS_NOITAN))
+        )
+       ) {
 
-  /* check for single jobs */
-  if (hasSingle) {
-    DBG_INFO(AQHBCI_LOGDOMAIN,
-             "Queue already contains a job which wants to be left alone");
-    return AH_JobQueueAddResultQueueFull;
-  }
-
-  /* check if this job is single and there already are jobs in the queue */
-  if (((AH_Job_GetFlags(j) & AH_JOB_FLAGS_SINGLE) ||
-       (AH_Job_GetFlags(j) & AH_JOB_FLAGS_DLGJOB)) && jobCount) {
-    DBG_INFO(AQHBCI_LOGDOMAIN,
-             "Queue already contains jobs and this one has the SINGLE flag");
-    return AH_JobQueueAddResultJobLimit;
-  }
-
-  /* check if adding this job would exceed the limit of jobs of this kind */
-  if (jobsPerMsg && thisJobTypeCount>jobsPerMsg) {
-    DBG_INFO(AQHBCI_LOGDOMAIN,
-             "Too many jobs of this kind (limit is %d)", jobsPerMsg);
-    return AH_JobQueueAddResultJobLimit;
-  }
-
-  /* check for maximum of different job types per message */
-  if (maxJobTypes && jobTypeCount>maxJobTypes) {
-    DBG_INFO(AQHBCI_LOGDOMAIN,
-             "Too many different job types (limit is %d)", maxJobTypes);
-    return AH_JobQueueAddResultJobLimit;
-  }
-
-  /* check for signers */
-  if (!jobCount && !GWEN_StringList_Count(jq->signers)) {
-    const GWEN_STRINGLIST *sl;
-
-    /* no jobs in queue and no signers,
-     * so simply copy the signers of this job */
-    sl=AH_Job_GetSigners(j);
-    if (sl) {
-      DBG_INFO(AQHBCI_LOGDOMAIN, "Copying signers from job to queue");
-      GWEN_StringList_free(jq->signers);
-      jq->signers=GWEN_StringList_dup(sl);
-    }
-  }
-  else {
-    const GWEN_STRINGLIST *sl;
-    GWEN_STRINGLISTENTRY *se;
-
-    sl=AH_Job_GetSigners(j);
-    if (GWEN_StringList_Count(sl)!=GWEN_StringList_Count(jq->signers)) {
       DBG_INFO(AQHBCI_LOGDOMAIN,
-               "Number of signers of the job differs from that of the queue");
+               "Encryption/TAN/SysId flags for queue and this job differ");
       return AH_JobQueueAddResultJobLimit;
     }
-    se=GWEN_StringList_FirstEntry(sl);
-    while(se) {
-      if (!GWEN_StringList_HasString(jq->signers,
-                                     GWEN_StringListEntry_Data(se))) {
-        DBG_INFO(AQHBCI_LOGDOMAIN, "Signers of the job differ from those of the queue");
+
+    /* check for single jobs */
+    if (hasSingle) {
+      DBG_INFO(AQHBCI_LOGDOMAIN,
+               "Queue already contains a job which wants to be left alone");
+      return AH_JobQueueAddResultQueueFull;
+    }
+
+    /* check if this job is single and there already are jobs in the queue */
+    if (((AH_Job_GetFlags(j) & AH_JOB_FLAGS_SINGLE) ||
+         (AH_Job_GetFlags(j) & AH_JOB_FLAGS_DLGJOB)) && jobCount) {
+      DBG_INFO(AQHBCI_LOGDOMAIN,
+               "Queue already contains jobs and this one has the SINGLE flag");
+      return AH_JobQueueAddResultJobLimit;
+    }
+
+    /* check if adding this job would exceed the limit of jobs of this kind */
+    if (jobsPerMsg && thisJobTypeCount>jobsPerMsg) {
+      DBG_INFO(AQHBCI_LOGDOMAIN,
+               "Too many jobs of this kind (limit is %d)", jobsPerMsg);
+      return AH_JobQueueAddResultJobLimit;
+    }
+
+    /* check for maximum of different job types per message */
+    if (maxJobTypes && jobTypeCount>maxJobTypes) {
+      DBG_INFO(AQHBCI_LOGDOMAIN,
+               "Too many different job types (limit is %d)", maxJobTypes);
+      return AH_JobQueueAddResultJobLimit;
+    }
+
+    /* check for signers */
+    if (!jobCount && !GWEN_StringList_Count(jq->signers)) {
+      const GWEN_STRINGLIST *sl;
+
+      /* no jobs in queue and no signers,
+       * so simply copy the signers of this job */
+      sl=AH_Job_GetSigners(j);
+      if (sl) {
+        DBG_INFO(AQHBCI_LOGDOMAIN, "Copying signers from job to queue");
+        GWEN_StringList_free(jq->signers);
+        jq->signers=GWEN_StringList_dup(sl);
+      }
+    }
+    else {
+      const GWEN_STRINGLIST *sl;
+      GWEN_STRINGLISTENTRY *se;
+
+      sl=AH_Job_GetSigners(j);
+      if (GWEN_StringList_Count(sl)!=GWEN_StringList_Count(jq->signers)) {
+        DBG_INFO(AQHBCI_LOGDOMAIN,
+                 "Number of signers of the job differs from that of the queue");
         return AH_JobQueueAddResultJobLimit;
       }
-      se=GWEN_StringListEntry_Next(se);
-    } /* while se */
+      se=GWEN_StringList_FirstEntry(sl);
+      while(se) {
+        if (!GWEN_StringList_HasString(jq->signers,
+                                       GWEN_StringListEntry_Data(se))) {
+          DBG_INFO(AQHBCI_LOGDOMAIN, "Signers of the job differ from those of the queue");
+          return AH_JobQueueAddResultJobLimit;
+        }
+        se=GWEN_StringListEntry_Next(se);
+      } /* while se */
+    }
+
+    /* adjust queue flags according to current job */
+    if (AH_Job_GetFlags(j) & AH_JOB_FLAGS_CRYPT)
+      jq->flags|=AH_JOBQUEUE_FLAGS_CRYPT;
+    if (AH_Job_GetFlags(j) & AH_JOB_FLAGS_SIGN)
+      jq->flags|=AH_JOBQUEUE_FLAGS_SIGN;
+    if (AH_Job_GetFlags(j) & AH_JOB_FLAGS_NEEDTAN)
+      jq->flags|=AH_JOBQUEUE_FLAGS_NEEDTAN;
+    if (AH_Job_GetFlags(j) & AH_JOB_FLAGS_NOSYSID)
+      jq->flags|=AH_JOBQUEUE_FLAGS_NOSYSID;
+    if (AH_Job_GetFlags(j) & AH_JOB_FLAGS_NOITAN)
+      jq->flags|=AH_JOBQUEUE_FLAGS_NOITAN;
   }
 
   /* actually add job to queue */
   AH_Job_List_Add(j, jq->jobs);
   AH_Job_SetStatus(j, AH_JobStatusEnqueued);
 
-  /* adjust queue flags according to current job */
-  if (AH_Job_GetFlags(j) & AH_JOB_FLAGS_CRYPT)
-    jq->flags|=AH_JOBQUEUE_FLAGS_CRYPT;
-  if (AH_Job_GetFlags(j) & AH_JOB_FLAGS_SIGN)
-    jq->flags|=AH_JOBQUEUE_FLAGS_SIGN;
-  if (AH_Job_GetFlags(j) & AH_JOB_FLAGS_NEEDTAN)
-    jq->flags|=AH_JOBQUEUE_FLAGS_NEEDTAN;
-  if (AH_Job_GetFlags(j) & AH_JOB_FLAGS_NOSYSID)
-    jq->flags|=AH_JOBQUEUE_FLAGS_NOSYSID;
-
   DBG_INFO(AQHBCI_LOGDOMAIN, "Job added to the queue");
   return AH_JobQueueAddResultOk;
 }
@@ -359,6 +372,7 @@ AH_MSG *AH_JobQueue_ToMessage(AH_JOBQUEUE *jq, AH_DIALOG *dlg){
       unsigned int lastSeg;
       GWEN_DB_NODE *jargs;
       GWEN_XMLNODE *jnode;
+      GWEN_BUFFER *msgBuf;
 
       DBG_INFO(AQHBCI_LOGDOMAIN, "Encoding job \"%s\"", AH_Job_GetName(j));
       jargs=AH_Job_GetArguments(j);
@@ -379,6 +393,8 @@ AH_MSG *AH_JobQueue_ToMessage(AH_JOBQUEUE *jq, AH_DIALOG *dlg){
       }
 
       firstSeg=AH_Msg_GetCurrentSegmentNumber(msg);
+      msgBuf=AH_Msg_GetBuffer(msg);
+      assert(msgBuf);
       lastSeg=AH_Msg_AddNode(msg, jnode, jargs);
       if (!lastSeg) {
         DBG_INFO(AQHBCI_LOGDOMAIN, "Could not encode job \"%s\"",
@@ -388,10 +404,13 @@ AH_MSG *AH_JobQueue_ToMessage(AH_JOBQUEUE *jq, AH_DIALOG *dlg){
       else {
         AH_Job_SetFirstSegment(j, firstSeg);
         AH_Job_SetLastSegment(j, lastSeg);
-        DBG_INFO(AQHBCI_LOGDOMAIN, "Job \"%s\" encoded",
-                 AH_Job_GetName(j));
-        AH_Job_SetStatus(j, AH_JobStatusEncoded);
-        encodedJobs++;
+
+        if (AH_Job_GetStatus(j)!=AH_JobStatusError) {
+          DBG_INFO(AQHBCI_LOGDOMAIN, "Job \"%s\" encoded",
+                   AH_Job_GetName(j));
+          AH_Job_SetStatus(j, AH_JobStatusEncoded);
+          encodedJobs++;
+        }
       }
     } /* if status matches */
     j=AH_Job_List_Next(j);
@@ -507,48 +526,6 @@ int AH_JobQueue__CheckTans(AH_JOBQUEUE *jq){
 
 
 
-void AH_JobQueue__AddAsUtf8(GWEN_BUFFER *buf, const char *txt) {
-  while(*txt) {
-    switch((unsigned char)(*txt)) {
-    case 0xc4: /* AE */
-      GWEN_Buffer_AppendByte(buf, 0xc3);
-      GWEN_Buffer_AppendByte(buf, 0x84);
-      break;
-    case 0xd6: /* OE */
-      GWEN_Buffer_AppendByte(buf, 0xc3);
-      GWEN_Buffer_AppendByte(buf, 0x96);
-      break;
-    case 0xdc: /* UE */
-      GWEN_Buffer_AppendByte(buf, 0xc3);
-      GWEN_Buffer_AppendByte(buf, 0x9c);
-      break;
-    case 0xdf: /* sharp-s */
-      GWEN_Buffer_AppendByte(buf, 0xc3);
-      GWEN_Buffer_AppendByte(buf, 0x9f);
-      break;
-    case 0xe4: /* ae */
-      GWEN_Buffer_AppendByte(buf, 0xc3);
-      GWEN_Buffer_AppendByte(buf, 0xa4);
-      break;
-    case 0xf6: /* oe */
-      GWEN_Buffer_AppendByte(buf, 0xc3);
-      GWEN_Buffer_AppendByte(buf, 0xb6);
-      break;
-    case 0xfc: /* ue */
-      GWEN_Buffer_AppendByte(buf, 0xc3);
-      GWEN_Buffer_AppendByte(buf, 0xbc);
-      break;
-    default:
-      if (isascii(*txt))
-        GWEN_Buffer_AppendByte(buf, *txt);
-      else
-        GWEN_Buffer_AppendByte(buf, ' ');
-    }
-    txt++;
-  } /* while */
-}
-
-
 int AH_JobQueue_DispatchMessage(AH_JOBQUEUE *jq,
                                 AH_MSG *msg,
                                 GWEN_DB_NODE *db) {
@@ -594,6 +571,7 @@ int AH_JobQueue_DispatchMessage(AH_JOBQUEUE *jq,
       while(dbResult) {
         rcode=GWEN_DB_GetIntValue(dbResult, "resultcode", 0, 0);
         p=GWEN_DB_GetCharValue(dbResult, "text", 0, "");
+
         if (rcode>=9000 && rcode<10000) {
 	  DBG_INFO(AQHBCI_LOGDOMAIN,
 		   "Result: Error (%d: %s)", rcode, p);
@@ -625,7 +603,7 @@ int AH_JobQueue_DispatchMessage(AH_JOBQUEUE *jq,
           snprintf(numbuf, sizeof(numbuf), "%04d", rcode);
           GWEN_Buffer_AppendString(logmsg, numbuf);
           GWEN_Buffer_AppendString(logmsg, " - ");
-          AH_JobQueue__AddAsUtf8(logmsg, p);
+          GWEN_Buffer_AppendString(logmsg, p);
           if (isMsgResult)
             GWEN_Buffer_AppendString(logmsg, " (M)");
           else
@@ -886,7 +864,7 @@ int AH_JobQueue_DispatchMessage(AH_JOBQUEUE *jq,
               if (jq->usedPin) {
                 AH_MEDIUM *m;
 
-                DBG_ERROR(AQHBCI_LOGDOMAIN, "Bad signature");
+                DBG_ERROR(AQHBCI_LOGDOMAIN, "Bad pin");
                 m=AH_User_GetMedium(jq->user);
                 assert(m);
                 if (AH_User_GetCryptMode(jq->user)==AH_CryptMode_Pintan) {
@@ -912,6 +890,10 @@ int AH_JobQueue_DispatchMessage(AH_JOBQUEUE *jq,
             AH_Job_AddResponse(j, GWEN_DB_Group_dup(dbResponse));
             AH_Job_SetStatus(j, AH_JobStatusAnswered);
           }
+          else {
+            DBG_ERROR(AQHBCI_LOGDOMAIN,
+                      "Status %d of job doesn't match", st);
+          }
           j=AH_Job_List_Next(j);
         } /* while */
         GWEN_DB_Group_free(dbResponse);
@@ -972,17 +954,25 @@ int AH_JobQueue_DispatchMessage(AH_JOBQUEUE *jq,
   /* set usedTan status accordingly */
   j=AH_Job_List_First(jq->jobs);
   while(j) {
-    AH_JOB_STATUS st;
+    const char *utan;
 
-    st=AH_Job_GetStatus(j);
-    if (st==AH_JobStatusSent ||
-        st==AH_JobStatusAnswered) {
-      if (jq->usedTan) {
+    utan=AH_Job_GetUsedTan(j);
+    if (utan) {
+      AH_JOB_STATUS st;
+
+      AH_Job_AddFlags(j, AH_JOB_FLAGS_TANUSED);
+      st=AH_Job_GetStatus(j);
+      if (st==AH_JobStatusSent ||
+          st==AH_JobStatusAnswered) {
         if (tanRecycle)
           AH_Job_SubFlags(j, AH_JOB_FLAGS_TANUSED);
-        else
-          AH_Job_AddFlags(j, AH_JOB_FLAGS_TANUSED);
       }
+      else {
+        DBG_WARN(AQHBCI_LOGDOMAIN, "Bad status %d", st);
+      }
+    }
+    else {
+      DBG_WARN(AQHBCI_LOGDOMAIN, "No TAN");
     }
     j=AH_Job_List_Next(j);
   } /* while */
@@ -999,7 +989,7 @@ int AH_JobQueue_DispatchMessage(AH_JOBQUEUE *jq,
 
   if (abortQueue) {
     DBG_NOTICE(AQHBCI_LOGDOMAIN,
-	       "Aboting queue");
+	       "Aborting queue");
     return AB_ERROR_ABORTED;
   }
 
