@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: jobqueue_p.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: jobqueue_p.h,v 1.2 2006/01/13 13:59:59 cstim Exp $
+    cvs         : $Id: jobqueue_p.h 1043 2006-07-04 11:12:59Z martin $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -39,8 +39,6 @@ static void AH_JobQueue_SetUsedTan(AH_JOBQUEUE *jq, const char *s);
 static void AH_JobQueue_SetUsedPin(AH_JOBQUEUE *jq, const char *s);
 static int AH_JobQueue__CheckTans(AH_JOBQUEUE *jq);
 
-static void AH_JobQueue__AddAsUtf8(GWEN_BUFFER *buf, const char *txt);
-
 
 #endif /* AH_JOBQUEUE_P_H */
 
