@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: account.c,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: account.c,v 1.4 2006/03/02 14:09:20 aquamaniac Exp $
+    cvs         : $Id: account.c 959 2006-03-02 14:09:21Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
