@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: dialog.c,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: dialog.c,v 1.10 2006/02/22 19:39:00 aquamaniac Exp $
+    cvs         : $Id: dialog.c 1041 2006-07-03 17:14:56Z martin $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -640,6 +640,40 @@ int AH_Dialog_Disconnect(AH_DIALOG *dlg, int timeout) {
 
 
 
+void AH_Dialog_SetItanMethod(AH_DIALOG *dlg, GWEN_TYPE_UINT32 i) {
+  assert(dlg);
+  dlg->itanMethod=i;
+}
+
+
+
+GWEN_TYPE_UINT32 AH_Dialog_GetItanMethod(const AH_DIALOG *dlg) {
+  assert(dlg);
+  return dlg->itanMethod;
+}
+
+
+
+int AH_Dialog_GetItanProcessType(const AH_DIALOG *dlg) {
+  assert(dlg);
+  return dlg->itanProcessType;
+}
+
+
+
+void AH_Dialog_SetItanProcessType(AH_DIALOG *dlg, int i) {
+  assert(dlg);
+  dlg->itanProcessType=i;
+}
+
+
+
+
+
+
+
+
+
 
 
 
