@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: dialog_p.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: dialog_p.h,v 1.4 2006/01/13 13:59:59 cstim Exp $
+    cvs         : $Id: dialog_p.h 1041 2006-07-03 17:14:56Z martin $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -34,6 +34,10 @@ struct AH_DIALOG {
 
   GWEN_DB_NODE *globalValues;
   char *logName;
+
+  GWEN_TYPE_UINT32 itanMethod;
+  int itanProcessType;
+
 };
 
 
