@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: hbci-updates.c,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: hbci-updates.c,v 1.7 2006/03/02 17:20:46 aquamaniac Exp $
+    cvs         : $Id: hbci-updates.c 1041 2006-07-03 17:14:56Z martin $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -133,6 +133,14 @@ int AH_HBCI_UpdateDbUser(AH_HBCI *hbci, GWEN_DB_NODE *db) {
       }
     }
 
+    if (oldVersion<((2<<24) | (1<<16) | (1<<8) | 1)) {
+      rv=AH_HBCI_UpdateUser_2_1_1_1(hbci, db);
+      if (rv) {
+        DBG_INFO(AQHBCI_LOGDOMAIN, "here (%d)", rv);
+        return rv;
+      }
+    }
+
     /* insert more updates here */
 
 
@@ -815,6 +823,16 @@ int AH_HBCI_UpdateUser_1_9_7_7(AH_HBCI *hbci, GWEN_DB_NODE *db) {
 
 
 
+int AH_HBCI_UpdateUser_2_1_1_1(AH_HBCI *hbci, GWEN_DB_NODE *db) {
+  GWEN_TYPE_UINT32 tm;
+
+  tm=AH_USER_TANMETHOD_SINGLE_STEP;
+  AH_User_TanMethods_toDb(db, "tanMethods", tm);
+  return 0;
+}
+
+
+
 
 
 
