@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: hbci-updates_p.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: hbci-updates_p.h,v 1.4 2006/03/02 14:09:21 aquamaniac Exp $
+    cvs         : $Id: hbci-updates_p.h 1035 2006-06-29 23:41:18Z martin $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -66,6 +66,13 @@ static int AH_HBCI_Update_Any(AH_HBCI *hbci, GWEN_DB_NODE *db);
  * This update converts AH_BPDADDR groups to GWEN_URL strings.
  */
 static int AH_HBCI_UpdateUser_1_9_7_7(AH_HBCI *hbci, GWEN_DB_NODE *db);
+
+/**
+ * This update adds the variable "tanMethods" with an initial value of
+ * "singleStep"
+ */
+static int AH_HBCI_UpdateUser_2_1_1_1(AH_HBCI *hbci, GWEN_DB_NODE *db);
+
 /*@}*/
 
 
