@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: hbci_l.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: hbci_l.h,v 1.8 2006/02/22 19:39:00 aquamaniac Exp $
+    cvs         : $Id: hbci_l.h 1043 2006-07-04 11:12:59Z martin $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -247,11 +247,6 @@ AQHBCI_API
 void AH_HBCI_SetConnectTimeout(AH_HBCI *hbci, int i);
 
 
-AQHBCI_API
-void AH_HBCI_HbciToUtf8(const char *p,
-                        int size,
-                        GWEN_BUFFER *buf);
-
 AQHBCI_API
 int AH_HBCI_CheckStringSanity(const char *s);
 
