@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: medium.c,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: medium.c,v 1.12 2006/03/24 15:27:55 aquamaniac Exp $
+    cvs         : $Id: medium.c 1069 2006-09-29 12:48:25Z martin $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -975,7 +975,6 @@ GWEN_BUFFER *AH_Medium_GenerateMsgKey(AH_MEDIUM *m) {
 
 
 
-
 AH_MEDIUM_RESULT AH_Medium_Encrypt(AH_MEDIUM *m,
                                    GWEN_BUFFER *msgbuf,
                                    GWEN_BUFFER *encryptbuf,
@@ -1447,6 +1446,63 @@ int AH_Medium_InputTan(AH_MEDIUM *m,
 
 
 
+int AH_Medium_InputTanWithChallenge(AH_MEDIUM *m,
+                                    const char *challenge,
+                                    char *pwbuffer,
+                                    int minLen,
+                                    int maxLen){
+  int rv;
+  const char *name;
+  char buffer[512];
+
+  assert(m);
+
+  buffer[0]=0;
+  buffer[sizeof(buffer)-1]=0;
+  snprintf(buffer, sizeof(buffer)-1,
+	   I18N("Please enter the TAN\n"
+                "for %s.\n"
+                "The server provided the following challenge:\n"
+                "%s"
+                "<html>"
+                "<p>"
+		"Please enter the next TAN for <i>%s</i>."
+                "</p>"
+                "<p>"
+                "The server provided the following challenge:"
+                "</p>"
+                "<p align=\"center\" >"
+                "<font color=\"blue\">%s</font>"
+                "</p>"
+                "</html>"),
+           AH_Medium_GetDescriptiveName(m), challenge,
+           AH_Medium_GetDescriptiveName(m), challenge);
+
+  name=AH_Medium_GetMediumName(m);
+  if (name) {
+    rv=AB_Banking_GetTan(AH_HBCI_GetBankingApi(m->hbci),
+			 name,
+			 I18N("Enter TAN"),
+			 buffer,
+			 pwbuffer,
+			 minLen,
+			 maxLen);
+  }
+  else {
+    rv=AB_Banking_InputBox(AH_HBCI_GetBankingApi(m->hbci),
+			   AB_BANKING_INPUT_FLAGS_NUMERIC|
+			   AB_BANKING_INPUT_FLAGS_SHOW,
+			   I18N("Enter TAN"),
+			   buffer,
+			   pwbuffer,
+			   minLen,
+			   maxLen);
+  }
+  return rv;
+}
+
+
+
 int AH_Medium_SetTanStatus(AH_MEDIUM *m,
                            const char *tan,
                            AB_BANKING_TANSTATUS status){
@@ -2134,6 +2190,47 @@ void AH_Medium_SetUniqueId(AH_MEDIUM *m, GWEN_TYPE_UINT32 id) {
 
 
 
+AH_MEDIUM_RESULT AH_Medium_EncryptWithKey(AH_MEDIUM *m,
+					  GWEN_BUFFER *msgbuf,
+					  GWEN_BUFFER *encryptbuf,
+					  GWEN_CRYPTKEY *sessionKey) {
+  GWEN_ERRORCODE err;
+
+  assert(m);
+
+  if (!AH_Medium_IsMounted(m)) {
+    DBG_ERROR(AQHBCI_LOGDOMAIN, "Medium is not mounted");
+    return AH_MediumResultGenericError;
+  }
+
+  /* padd message */
+  DBG_DEBUG(AQHBCI_LOGDOMAIN, "Padding with ANSI X9.23");
+  if (GWEN_Padd_PaddWithANSIX9_23(msgbuf)) {
+    DBG_INFO(AQHBCI_LOGDOMAIN, "here");
+    return AH_MediumResultGenericError;
+  }
+  DBG_DEBUG(AQHBCI_LOGDOMAIN, "Padding with ANSI X9.23: done");
+
+  /* encrypt message */
+  DBG_DEBUG(AQHBCI_LOGDOMAIN, "Encrypting with session key");
+  err=GWEN_CryptKey_Encrypt(sessionKey,
+                            msgbuf,
+                            encryptbuf);
+  if (!GWEN_Error_IsOk(err)) {
+    DBG_INFO(AQHBCI_LOGDOMAIN, "here");
+    return AH_MediumResultGenericError;
+  }
+  DBG_DEBUG(AQHBCI_LOGDOMAIN, "Encrypting with session key: done");
+
+  return AH_MediumResultOk;
+}
+
+
+
+
+
+
+
 
 
 
