@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: message_p.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: message_p.h,v 1.4 2006/01/13 13:59:59 cstim Exp $
+    cvs         : $Id: message_p.h 1037 2006-06-30 02:41:56Z martin $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -60,11 +60,14 @@ struct AH_MSG {
 
   char *usedPin;
 
+  int itanMethod;
+  int itanHashMode;
+  GWEN_BUFFER *itanHashBuffer;
+
   GWEN_DB_NODE *decodedMsg;
 };
 
 
-static void AH_Msg_SetTan(AH_MSG *hmsg, const char *s);
 static void AH_Msg_SetPin(AH_MSG *hmsg, const char *s);
 
 static int AH_Msg_AddMsgTail(AH_MSG *hmsg);
@@ -109,6 +112,13 @@ static int AH_Msg_PrepareCryptoSegDec(AH_MSG *hmsg,
                                       GWEN_BUFFER *msgkeybuf);
 
 
+static GWEN_ERRORCODE AH_Msg__AnonHnsha(const char *psegment,
+                                        unsigned int slen,
+                                        GWEN_BUFFEREDIO *bio);
+static GWEN_ERRORCODE AH_Msg__AnonHkpae(const char *psegment,
+                                        unsigned int slen,
+                                        GWEN_BUFFEREDIO *bio);
+
 
 #endif /* AH_MESSAGE_P_H */
 
