@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: msgengine.c,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: msgengine.c,v 1.4 2006/01/13 13:59:59 cstim Exp $
+    cvs         : $Id: msgengine.c 764 2006-01-13 14:00:00Z cstim $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
