@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: user_p.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: user_p.h,v 1.3 2006/02/22 19:39:00 aquamaniac Exp $
+    cvs         : $Id: user_p.h 1041 2006-07-03 17:14:56Z martin $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -27,6 +27,7 @@ struct AH_USER {
   AH_BPD *bpd;
 
   GWEN_TYPE_UINT32 flags;
+  GWEN_TYPE_UINT32 tanMethods;
 };
 
 static void AH_User_freeData(void *bp, void *p);
