@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: adduser.c,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: adduser.c,v 1.7 2006/03/24 14:30:57 aquamaniac Exp $
+ cvs         : $Id: adduser.c 979 2006-03-24 14:30:57Z aquamaniac $
  begin       : Tue May 03 2005
  copyright   : (C) 2005 by Martin Preuss
  email       : martin@libchipcard.de
