@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: globals.h,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: globals.h,v 1.4 2006/02/22 19:39:01 aquamaniac Exp $
+ cvs         : $Id: globals.h 1069 2006-09-29 12:48:25Z martin $
  begin       : Tue May 03 2005
  copyright   : (C) 2005 by Martin Preuss
  email       : martin@libchipcard.de
@@ -107,6 +107,28 @@ int iniLetter(AB_BANKING *ab,
               int argc,
               char **argv);
 
+int getItanModes(AB_BANKING *ab,
+                 GWEN_DB_NODE *dbArgs,
+                 int argc,
+                 char **argv);
+
+int changePin(AB_BANKING *ab,
+              GWEN_DB_NODE *dbArgs,
+              int argc,
+              char **argv);
+
+
+
+int test1(AB_BANKING *ab,
+          GWEN_DB_NODE *dbArgs,
+          int argc,
+          char **argv);
+
+int test2(AB_BANKING *ab,
+          GWEN_DB_NODE *dbArgs,
+          int argc,
+          char **argv);
+
 
 #endif
 
