@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: listmedia.c,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: listmedia.c,v 1.2 2006/02/22 19:39:01 aquamaniac Exp $
+ cvs         : $Id: listmedia.c 950 2006-02-22 19:39:02Z aquamaniac $
  begin       : Tue May 03 2005
  copyright   : (C) 2005 by Martin Preuss
  email       : martin@libchipcard.de
