@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: resetkeys.c,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: resetkeys.c,v 1.4 2006/03/17 10:35:21 cstim Exp $
+ cvs         : $Id: resetkeys.c 964 2006-03-17 10:35:21Z cstim $
  begin       : Tue May 03 2005
  copyright   : (C) 2005 by Martin Preuss
  email       : martin@libchipcard.de
