@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: hbcixml.cpp,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: hbcixml.cpp,v 1.3 2005/08/26 10:10:31 cstim Exp $
+ cvs         : $Id: hbcixml.cpp 577 2005-08-26 10:10:31Z cstim $
  begin       : Thu Jul 03 2003
  copyright   : (C) 2003 by Martin Preuss
  email       : martin@libchipcard.de
