@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: cfgtabpageuserhbci.h,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: cfgtabpageuserhbci.h,v 1.4 2006/02/22 19:39:01 aquamaniac Exp $
+ cvs         : $Id: cfgtabpageuserhbci.h 1041 2006-07-03 17:14:56Z martin $
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
@@ -44,6 +44,7 @@ public slots:
   void slotGetServerKeys();
   void slotGetSysId();
   void slotGetAccounts();
+  void slotGetItanModes();
   void slotFinishUser();
 
 private:
