@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: selectmode.h,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: selectmode.h,v 1.3 2006/02/22 19:39:01 aquamaniac Exp $
+ cvs         : $Id: selectmode.h 950 2006-02-22 19:39:02Z aquamaniac $
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
