@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: a_finished.cpp,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: a_finished.cpp,v 1.3 2006/02/22 19:39:02 aquamaniac Exp $
+ cvs         : $Id: a_finished.cpp 1062 2006-09-19 20:15:31Z christian $
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
@@ -32,9 +32,9 @@ ActionFinished::ActionFinished(Wizard *w)
   QLabel *tl;
 
   tl=new QLabel(this, "FinishedText");
-  tl->setText("<qt>"
+  tl->setText(tr("<qt>"
               "The new user has now been setup. Have fun."
-              "</qt>");
+		 "</qt>"));
   addWidget(tl);
 }
 
