@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: a_finished.h,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: a_finished.h,v 1.1 2005/11/05 01:16:14 aquamaniac Exp $
+ cvs         : $Id: a_finished.h 643 2005-11-05 01:16:14Z aquamaniac $
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
