@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: a_wait.cpp,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: a_wait.cpp,v 1.2 2006/02/22 19:39:02 aquamaniac Exp $
+ cvs         : $Id: a_wait.cpp 1062 2006-09-19 20:15:31Z christian $
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
@@ -32,7 +32,7 @@ ActionWait::ActionWait(Wizard *w)
   QLabel *tl;
 
   tl=new QLabel(this, "WaitText");
-  tl->setText("<qt>"
+  tl->setText(tr("<qt>"
               "<p>"
               "The new user has now been setup partly."
               "</p>"
@@ -45,7 +45,7 @@ ActionWait::ActionWait(Wizard *w)
               "of the application. You can then finish the setup of this "
               "user."
               "</p>"
-              "</qt>");
+		 "</qt>"));
   addWidget(tl);
 }
 
