@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: a_wait.h,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: a_wait.h,v 1.1 2005/11/22 16:44:32 aquamaniac Exp $
+ cvs         : $Id: a_wait.h 676 2005-11-22 16:44:32Z aquamaniac $
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
