@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: w_rdh_import.h,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: w_rdh_import.h,v 1.3 2006/03/02 14:09:21 aquamaniac Exp $
+ cvs         : $Id: w_rdh_import.h 959 2006-03-02 14:09:21Z aquamaniac $
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
