@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: w_rdh_new.h,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: w_rdh_new.h,v 1.3 2006/01/13 14:00:00 cstim Exp $
+ cvs         : $Id: w_rdh_new.h 764 2006-01-13 14:00:00Z cstim $
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
