@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: provider_p.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: provider_p.h,v 1.1 2006/01/27 03:04:20 aquamaniac Exp $
+    cvs         : $Id: provider_p.h 865 2006-01-27 03:04:21Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
