@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: aqofxconnect_l.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: aqofxconnect_l.h,v 1.1 2005/08/08 02:24:41 aquamaniac Exp $
+    cvs         : $Id: aqofxconnect_l.h 418 2005-08-08 02:24:41Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
