@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: context.c,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: context.c,v 1.3 2006/01/13 14:00:00 cstim Exp $
+    cvs         : $Id: context.c 1019 2006-05-16 13:09:24Z martin $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -103,12 +103,16 @@ int AO_Context_Update(AO_CONTEXT *ctx){
     pro=AB_User_GetProvider(ctx->user);
     assert(pro);
 
-    s=AB_User_GetBankCode(ctx->user);
-    if (s && isdigit(*s))
-      /* only copy bank id if it is a number (-> routing number)
-       * otherwise it serves only identification purposes for this backend
-       * and doesn't represent a routing number */
-      strncpy(ctx->ai->bankid, s, OFX_BANKID_LENGTH-1);
+    if (!(AO_User_GetFlags(ctx->user) &
+          AO_USER_FLAGS_EMPTY_BANKID)) {
+      /* only copy bank code if not forbidden by user */
+      s=AB_User_GetBankCode(ctx->user);
+      if (s && isdigit(*s))
+        /* only copy bank id if it is a number (-> routing number)
+         * otherwise it serves only identification purposes for this backend
+         * and doesn't represent a routing number */
+        strncpy(ctx->ai->bankid, s, OFX_BANKID_LENGTH-1);
+    }
 
     s=AO_User_GetBrokerId(ctx->user);
     if (s)
@@ -118,9 +122,12 @@ int AO_Context_Update(AO_CONTEXT *ctx){
     if (s)
       strncpy(ctx->fi->org, s, OFX_ORG_LENGTH-1);
 
-    s=AO_User_GetFid(ctx->user);
-    if (s)
-      strncpy(ctx->fi->fid, s, OFX_FID_LENGTH-1);
+    if (!(AO_User_GetFlags(ctx->user) &
+	  AO_USER_FLAGS_EMPTY_FID)) {
+      s=AO_User_GetFid(ctx->user);
+      if (s)
+	strncpy(ctx->fi->fid, s, OFX_FID_LENGTH-1);
+    }
 
     s=AB_User_GetUserId(ctx->user);
     if (s) {
