@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: provider.c,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: provider.c,v 1.8 2006/02/14 02:11:55 aquamaniac Exp $
+    cvs         : $Id: provider.c 1049 2006-07-12 13:44:24Z martin $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -859,7 +859,7 @@ int AO_Provider_SendAndReceive(AB_PROVIDER *pro,
   dp=GWEN_INHERIT_GETDATA(AB_PROVIDER, AO_PROVIDER, pro);
   assert(dp);
 
-  if (1) {
+  if (getenv("AQOFX_LOG_COMM")) {
     FILE *f;
 
     DBG_ERROR(AQOFXCONNECT_LOGDOMAIN,
@@ -962,7 +962,7 @@ int AO_Provider_SendAndReceive(AB_PROVIDER *pro,
   /* release connection ressources */
   GWEN_NetLayer_free(nl);
 
-  if (1) {
+  if (getenv("AQOFX_LOG_COMM")) {
     FILE *f;
 
     DBG_ERROR(AQOFXCONNECT_LOGDOMAIN,
@@ -1094,7 +1094,7 @@ int AO_Provider_RequestStatements(AB_PROVIDER *pro, AB_JOB *j,
   AO_PROVIDER *dp;
   AO_CONTEXT *ctx;
   char *msg;
-  GWEN_BUFFER *rbuf;
+  GWEN_BUFFER *rbuf=0;
   int rv;
   AB_USER *u;
   AB_ACCOUNT *a;
