@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: provider_p.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: provider_p.h,v 1.7 2006/02/14 02:11:55 aquamaniac Exp $
+    cvs         : $Id: provider_p.h 935 2006-02-14 02:11:55Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
