@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: user.c,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: user.c,v 1.4 2006/01/23 17:02:58 aquamaniac Exp $
+    cvs         : $Id: user.c 1019 2006-05-16 13:09:24Z martin $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -69,6 +69,10 @@ GWEN_TYPE_UINT32 AO_User_Flags_fromDb(GWEN_DB_NODE *db, const char *name) {
       f|=AO_USER_FLAGS_INVESTMENT;
     else if (strcasecmp(s, "billpay")==0)
       f|=AO_USER_FLAGS_BILLPAY;
+    else if (strcasecmp(s, "emptyBankId")==0)
+      f|=AO_USER_FLAGS_EMPTY_BANKID;
+    else if (strcasecmp(s, "emptyFid")==0)
+      f|=AO_USER_FLAGS_EMPTY_FID;
     else {
       DBG_ERROR(AQOFXCONNECT_LOGDOMAIN,
                 "Unknown user flag \"%s\"", s);
@@ -94,6 +98,12 @@ void AO_User_Flags_toDb(GWEN_DB_NODE *db, const char *name,
   if (f & AO_USER_FLAGS_BILLPAY)
     GWEN_DB_SetCharValue(db, GWEN_DB_FLAGS_DEFAULT, name,
                          "billpay");
+  if (f & AO_USER_FLAGS_EMPTY_BANKID)
+    GWEN_DB_SetCharValue(db, GWEN_DB_FLAGS_DEFAULT, name,
+			 "emptyBankId");
+  if (f & AO_USER_FLAGS_EMPTY_FID)
+    GWEN_DB_SetCharValue(db, GWEN_DB_FLAGS_DEFAULT, name,
+			 "emptyFid");
 }
 
 
