@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: user.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: user.h,v 1.3 2006/01/19 01:07:48 aquamaniac Exp $
+    cvs         : $Id: user.h 1019 2006-05-16 13:09:24Z martin $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -24,6 +24,8 @@
 #define AO_USER_FLAGS_STATEMENTS   0x00000002
 #define AO_USER_FLAGS_INVESTMENT   0x00000004
 #define AO_USER_FLAGS_BILLPAY      0x00000008
+#define AO_USER_FLAGS_EMPTY_BANKID 0x00000010
+#define AO_USER_FLAGS_EMPTY_FID    0x00000020
 
 
 
