@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: version.h.in,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: version.h.in,v 1.1 2005/08/08 02:24:41 aquamaniac Exp $
+ cvs         : $Id: version.h.in 418 2005-08-08 02:24:41Z aquamaniac $
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
@@ -15,12 +15,12 @@
 #define AQOFXCONNECT_VERSION_H
 
 #define AQOFXCONNECT_VERSION_MAJOR 2
-#define AQOFXCONNECT_VERSION_MINOR 0
-#define AQOFXCONNECT_VERSION_PATCHLEVEL 0
+#define AQOFXCONNECT_VERSION_MINOR 2
+#define AQOFXCONNECT_VERSION_PATCHLEVEL 3
 #define AQOFXCONNECT_VERSION_BUILD 0
 #define AQOFXCONNECT_VERSION_TAG "stable"
-#define AQOFXCONNECT_VERSION_FULL_STRING "2.0.0.0stable"
-#define AQOFXCONNECT_VERSION_STRING "2.0.0"
+#define AQOFXCONNECT_VERSION_FULL_STRING "2.2.3.0-stable"
+#define AQOFXCONNECT_VERSION_STRING "2.2.3"
 
 
 
