@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: user.h,v $
+ $RCSfile: provider_p.h,v $
                              -------------------
-    cvs         : $Id: user.h,v 1.3 2006/02/07 07:08:28 aquamaniac Exp $
+    cvs         : $Id: provider_p.h,v 1.3 2005/03/29 21:00:25 aquamaniac Exp $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
