@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: cfgtabpageuseryn.h,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: cfgtabpageuseryn.h,v 1.2 2006/02/27 17:51:11 aquamaniac Exp $
+ cvs         : $Id: cfgtabpageuseryn.h 957 2006-02-27 17:51:11Z aquamaniac $
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
