@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: generic.c,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: generic.c,v 1.7 2006/02/06 13:58:40 cstim Exp $
+    cvs         : $Id: generic.c 918 2006-02-06 13:58:40Z cstim $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
