@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: us_p.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: us_p.h,v 1.1 2005/04/15 04:58:02 aquamaniac Exp $
+    cvs         : $Id: us_p.h 281 2005-04-15 04:58:02Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
