@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: csv.c,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: csv.c,v 1.16 2005/09/10 09:08:25 cstim Exp $
+    cvs         : $Id: csv.c 1038 2006-07-03 03:01:30Z martin $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -92,7 +92,7 @@ int AH_ImExporterCSV_Import(AB_IMEXPORTER *ie,
   /* transform DB to transactions */
   GWEN_WaitCallback_Log(GWEN_LoggerLevelNotice,
                         I18N("Data imported, transforming to UTF-8"));
-  rv=AH_ImExporter_DbFromIso8859_1ToUtf8(dbData);
+  rv=AB_ImExporter_DbFromIso8859_1ToUtf8(dbData);
   if (rv) {
     GWEN_WaitCallback_Log(GWEN_LoggerLevelError,
                           "Error converting data");
