@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: dtaus.c,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: dtaus.c,v 1.4 2005/09/07 15:33:36 aquamaniac Exp $
+    cvs         : $Id: dtaus.c 602 2005-09-07 15:33:36Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
