@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: dtaus_p.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: dtaus_p.h,v 1.1 2004/09/17 09:08:57 aquamaniac Exp $
+    cvs         : $Id: dtaus_p.h 120 2004-09-17 09:08:57Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
