@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: eri.c,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: eri.c,v 1.22 2005/08/06 16:04:12 pdevrijer Exp $
+    cvs         : $Id: eri.c 412 2005-08-06 16:04:12Z pdevrijer $
     begin       : Thu 21-07-2005
     copyright   : (C) 2005 by Peter de Vrijer
     email       : pdevrijer@home.nl
