@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: ofx.c,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: ofx.c,v 1.5 2006/01/13 14:00:00 cstim Exp $
+ cvs         : $Id: ofx.c 764 2006-01-13 14:00:00Z cstim $
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
