@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: swift.c,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: swift.c,v 1.7 2006/01/25 18:08:20 aquamaniac Exp $
+    cvs         : $Id: swift.c 1009 2006-05-11 19:59:20Z martin $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -99,7 +99,7 @@ int AH_ImExporterSWIFT_Import(AB_IMEXPORTER *ie,
 			  I18N("Error importing data"));
     GWEN_DB_Group_free(dbData);
     GWEN_WaitCallback_Leave();
-    return rv;
+    return AB_ERROR_BAD_DATA;
   }
 
   GWEN_WaitCallback_Leave();
