@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: swift_p.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: swift_p.h,v 1.2 2005/08/23 06:25:02 aquamaniac Exp $
+    cvs         : $Id: swift_p.h 566 2005-08-23 06:25:03Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
