@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: dtaus-export.c,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: dtaus-export.c,v 1.7 2005/06/13 12:27:00 aquamaniac Exp $
+ cvs         : $Id: dtaus-export.c 1074 2006-10-06 16:00:33Z martin $
  begin       : Thu Apr 29 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
@@ -748,7 +748,7 @@ int AHB_DTAUS__Export(GWEN_DBIO *dbio,
   sumAccountIds=0;
 
   dst=GWEN_Buffer_new(0, 1024, 0, 1);
-  GWEN_Buffer_SetHardLimit(dst, 64*1024);
+  GWEN_Buffer_SetHardLimit(dst, AHB_DTAUS_HARDLIMIT);
 
   /* create A set */
   if (AHB_DTAUS__CreateSetA(dst, cfg)) {
