@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: dtaus-import.c,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: dtaus-import.c,v 1.13 2005/09/09 21:41:12 aquamaniac Exp $
+ cvs         : $Id: dtaus-import.c 609 2005-09-09 21:41:12Z aquamaniac $
  begin       : Thu Apr 29 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
