@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: swift.h,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: swift.h,v 1.1 2004/09/07 18:20:37 aquamaniac Exp $
+ cvs         : $Id: swift.h 96 2004-09-07 18:20:37Z aquamaniac $
  begin       : Mon May 02 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
