@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: chkacc.c,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: chkacc.c,v 1.3 2005/12/23 02:16:25 aquamaniac Exp $
+ cvs         : $Id: chkacc.c 727 2005-12-23 02:16:25Z aquamaniac $
  begin       : Tue May 03 2005
  copyright   : (C) 2005 by Martin Preuss
  email       : martin@libchipcard.de
