@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: tutorial3.c,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: tutorial3.c,v 1.2 2006/02/14 02:11:55 aquamaniac Exp $
+ cvs         : $Id: tutorial3.c 935 2006-02-14 02:11:55Z aquamaniac $
  begin       : Tue May 03 2005
  copyright   : (C) 2005 by Martin Preuss
  email       : martin@libchipcard.de
