@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: version.h.in,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: version.h.in,v 1.2 2005/04/07 16:50:57 aquamaniac Exp $
+ cvs         : $Id: version.h.in 269 2005-04-07 16:50:57Z aquamaniac $
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
@@ -15,17 +15,17 @@
 #define AQBANKING_VERSION_H
 
 #define AQBANKING_VERSION_MAJOR 2
-#define AQBANKING_VERSION_MINOR 0
-#define AQBANKING_VERSION_PATCHLEVEL 0
+#define AQBANKING_VERSION_MINOR 2
+#define AQBANKING_VERSION_PATCHLEVEL 3
 #define AQBANKING_VERSION_BUILD 0
 #define AQBANKING_VERSION_TAG "stable"
-#define AQBANKING_VERSION_FULL_STRING "2.0.0.0stable"
-#define AQBANKING_VERSION_STRING "2.0.0"
+#define AQBANKING_VERSION_FULL_STRING "2.2.3.0-stable"
+#define AQBANKING_VERSION_STRING "2.2.3"
 
 
-#define AQBANKING_SO_CURRENT 17
-#define AQBANKING_SO_REVISION 3
-#define AQBANKING_SO_AGE 1
+#define AQBANKING_SO_CURRENT 19
+#define AQBANKING_SO_REVISION 2
+#define AQBANKING_SO_AGE 3
 #define AQBANKING_SO_EFFECTIVE 16
 
 #endif /* AQBANKING_VERSION_H */
